#!/usr/bin/env python3
"""
Project: BRS-KB (BRS XSS Knowledge Base)
Company: EasyProTech LLC (www.easypro.tech)
Dev: Brabus
Date: 2025-12-26 UTC
Status: Refactored
Telegram: https://t.me/EasyProTech

GraphQL Payloads
"""


GRAPHQL_PAYLOADS = {
    # Query injection
    # Variable injection
    # Mutation injection
    # Batching attacks
    # Persisted query
}
