#!/usr/bin/env python3

"""
Project: BRS-KB (BRS XSS Knowledge Base)
Company: EasyProTech LLC (www.easypro.tech)
Dev: Brabus
Date: 2025-10-14 22:53:00 MSK
Status: Created
Telegram: https://t.me/easyprotech

Vulnerability Contexts Package
"""

# This package contains all vulnerability context modules
# Each module exports a DETAILS dictionary with vulnerability information
