#!/usr/bin/env python3

"""
Project: BRS-KB (BRS XSS Knowledge Base)
Company: EasyProTech LLC (www.easypro.tech)
Dev: Brabus
Date: 2025-12-04 12:00:00 UTC
Status: Created
Telegram: https://t.me/easyprotech

CLI package
Main entry point for CLI functionality
"""

from .cli import BRSKBCLI, main


__all__ = ["BRSKBCLI", "main"]
