#!/usr/bin/env python3
"""
Project: BRS-KB (BRS XSS Knowledge Base)
Company: EasyProTech LLC (www.easypro.tech)
Dev: Brabus
Date: 2025-12-27 UTC
Status: Active
Telegram: https://t.me/EasyProTech

Security Mechanism Bypass Payloads Package
"""

from .brs_kb_security_bypass import SECURITY_BYPASS_PAYLOADS, SECURITY_BYPASS_TOTAL


__all__ = [
    "SECURITY_BYPASS_PAYLOADS",
    "SECURITY_BYPASS_TOTAL",
]
