#!/usr/bin/env python3
"""
Project: BRS-KB (BRS XSS Knowledge Base)
Company: EasyProTech LLC (www.easypro.tech)
Dev: Brabus
Date: 2025-12-27 UTC
Status: Active
Telegram: https://t.me/EasyProTech

Advanced XSS Techniques Payloads Package
"""

from .brs_kb_advanced_techniques import ADVANCED_TECHNIQUES_PAYLOADS, ADVANCED_TECHNIQUES_TOTAL


__all__ = [
    "ADVANCED_TECHNIQUES_PAYLOADS",
    "ADVANCED_TECHNIQUES_TOTAL",
]
